<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

if ( ! function_exists( 'ultragym_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since  UltraGym Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function ultragym_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'ultragym_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'ultragym_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since UltraGym 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function ultragym_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'ultragym_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since  UltraGym Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function ultragym_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'ultragym_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'ultragym_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since  UltraGym Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function ultragym_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'ultragym_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Check if slider section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[slider_content_type]' )->value();
	return ultragym_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[slider_content_type]' )->value();
	return ultragym_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[slider_content_type]' )->value();
	return ultragym_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if slider separator section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_slider_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[slider_content_type]' )->value();
    return ultragym_pro_is_slider_section_enable( $control ) && !( 'category' == $content_type );
}
/**
 * Check if about section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[about_content_type]' )->value();
	return ultragym_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if slider section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[about_content_type]' )->value();
	return ultragym_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if slider section content type is custom.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_about_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[about_content_type]' )->value();
	return ultragym_pro_is_about_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if about section content type is custom.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_if_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[about_content_type]' )->value();
	return ultragym_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}


/**
 * Check if expert section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_expert_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[expert_section_enable]' )->value() );
}

/**
 * Check if expert section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_expert_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[expert_content_type]' )->value();
	return ultragym_pro_is_expert_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if expert section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_expert_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[expert_content_type]' )->value();
	return ultragym_pro_is_expert_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if expert section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_expert_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[expert_content_type]' )->value();
	return ultragym_pro_is_expert_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if expert section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_expert_section_separator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[expert_content_type]' )->value();
	return ultragym_pro_is_expert_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if video section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if video section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[video_content_type]' )->value();
	return ultragym_pro_is_video_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if slider section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[video_content_type]' )->value();
	return ultragym_pro_is_video_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if slider section content type is custom.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_video_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[video_content_type]' )->value();
	return ultragym_pro_is_video_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if video section content type is custom.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_if_video_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[video_content_type]' )->value();
	return ultragym_pro_is_video_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if contact section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[contact_section_enable]' )->value() );
}

/**
 * Check if service section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[service_content_type]' )->value();
	return ultragym_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if service section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[service_content_type]' )->value();
	return ultragym_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if service section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[service_content_type]' )->value();
	return ultragym_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if service separator section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_service_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[service_content_type]' )->value();
    return ultragym_pro_is_service_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if event section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[event_section_enable]' )->value() );
}

/**
 * Check if event section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[event_content_type]' )->value();
	return ultragym_pro_is_event_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if event section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[event_content_type]' )->value();
	return ultragym_pro_is_event_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if event section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[event_content_type]' )->value();
	return ultragym_pro_is_event_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if event separator section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_event_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[event_content_type]' )->value();
    return ultragym_pro_is_event_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_testimonial_section_enable( $control ) {
    return ( $control->manager->get_setting( 'ultragym_pro_theme_options[testimonial_section_enable]' )->value() );
}
/**
 * Check if testimonial section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_testimonial_section_content_page_enable( $control ) {
    $content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[testimonial_content_type]' )->value();
    return ultragym_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if testimonial section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_testimonial_section_content_post_enable( $control ) {
    $content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[testimonial_content_type]' )->value();
    return ultragym_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if testimonial section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_testimonial_section_content_category_enable( $control ) {
    $content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[testimonial_content_type]' )->value();
    return ultragym_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[blog_content_type]' )->value();
	return ultragym_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[blog_content_type]' )->value();
	return ultragym_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[blog_content_type]' )->value();
	return ultragym_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[blog_content_type]' )->value();
	return ultragym_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if blog separator section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_blog_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[blog_content_type]' )->value();
    return ultragym_pro_is_blog_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}


/**
 * Check if team section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[team_section_enable]' )->value() );
}


/**
 * Check if team section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[team_content_type]' )->value();
	return ultragym_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[team_content_type]' )->value();
	return ultragym_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[team_content_type]' )->value();
	return ultragym_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[team_content_type]' )->value();
	return ultragym_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}


/**
 * Check if counter section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[counter_section_enable]' )->value() );
}


/**
 * Check if featured_post section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[featured_post_section_enable]' )->value() );
}

/**
 * Check if featured_post section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_featured_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[featured_post_content_type]' )->value();
	return ultragym_pro_is_featured_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_post section seperator.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_featured_post_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[featured_post_content_type]' )->value();
	return ultragym_pro_is_featured_post_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if featured_post section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_featured_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[featured_post_content_type]' )->value();
	return ultragym_pro_is_featured_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_post section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[featured_post_content_type]' )->value();
	return ultragym_pro_is_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if call to action section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if call to action section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[cta_content_type]' )->value();
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[cta_section_enable]' )->value() && ('post' == $content_type) );
}
/**
 * Check if call to action section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[cta_content_type]' )->value();
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[cta_section_enable]' )->value() && ('page' == $content_type) );
}


/**
 * Check if popular_post section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'ultragym_pro_theme_options[popular_post_section_enable]' )->value() );
}

/**
 * Check if popular_post section content type is post.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[popular_post_content_type]' )->value();
	return ultragym_pro_is_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_post section content type is page.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[popular_post_content_type]' )->value();
	return ultragym_pro_is_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_post section content type is category.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[popular_post_content_type]' )->value();
	return ultragym_pro_is_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_post section content type is recent.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_popular_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[popular_post_content_type]' )->value();
	return ultragym_pro_is_popular_post_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if popular_post separator section is enabled.
 *
 * @since  UltraGym Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function ultragym_pro_is_popular_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'ultragym_pro_theme_options[popular_post_content_type]' )->value();
    return ultragym_pro_is_popular_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

//all layout 
function ultragym_pro_is_default_layout( $control ) {
	$design = $control->manager->get_setting( 'ultragym_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $design );
}

//pro layout 
function ultragym_pro_is_pro_layout( $control ) {
	$design = $control->manager->get_setting( 'ultragym_pro_theme_options[home_layout]' )->value();
	return ( 'pro-design' == $design );
}

//second layout 
function ultragym_pro_is_second_layout( $control ) {
	$design = $control->manager->get_setting( 'ultragym_pro_theme_options[home_layout]' )->value();
	return ( 'second-design' == $design );
}

//third layout 
function ultragym_pro_is_third_layout( $control ) {
	$design = $control->manager->get_setting( 'ultragym_pro_theme_options[home_layout]' )->value();
	return ( 'third-design' == $design );
}

//fourth layout 
function ultragym_pro_is_fourth_layout( $control ) {
	$design = $control->manager->get_setting( 'ultragym_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $design );
}

//fifth layout 
function ultragym_pro_is_fifth_layout( $control ) {
	$design = $control->manager->get_setting( 'ultragym_pro_theme_options[home_layout]' )->value();
	return ( 'fifth-design' == $design );
}

//sixth layout 
function ultragym_pro_is_sixth_layout( $control ) {
	$design = $control->manager->get_setting( 'ultragym_pro_theme_options[home_layout]' )->value();
	return ( 'sixth-design' == $design );
}