<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 * @return array An array of default values
 */

function ultragym_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$ultragym_pro_default_options = array(
		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#000',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#fe463a',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'lite-version',
		'home_layout'						=> 'pro-design',

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
				
		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,
		'admin_avatar'						=> (bool) true,

		// excerpt options
		'long_excerpt_length'               => 25,
		'read_more_text'           		    => esc_html__( 'Read More', 'ultra-gym-pro' ),

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'ultra-gym-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'ultra-gym-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'ultra-gym-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	    => (bool) true,
		'footer_scoial_menu'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'default_sortable' 						    => 'slider,featured_post,about,event,expert,cta,service,counter,video,testimonial,team,contact,popular_post,blog',

		'pro_sortable' 						    => 'slider,about,expert,service,video,testimonial,contact,blog',

		'second_sortable' 						    => 'slider,about,event,service,video,testimonial,team,contact,blog',

		'third_sortable' 						    => 'slider,about,service,counter,video,testimonial,blog',

		'fourth_sortable' 						    => 'slider,about,service,video,counter,testimonial,team,blog',

		'fifth_sortable' 						    => 'slider,about,cta,service,video,team,blog',

		'sixth_sortable' 						    => 'slider,featured_post,popular_post,blog',

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'ultra-gym-pro' ),
		'hide_date' 					    => (bool) false,
		'hide_author' 					    => (bool) false,
		'blog_column'						=> 'col-2',


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,

		/* Front Page */

		// Slider
		'slider_section_enable'				=> (bool) true,
		'slider_social_menu_enable'			=> (bool) true,
		'slider_content_type'				=> 'post',
		'slider_count'						=> 3,
		'slider_autoplay_enable'			=> (bool) false,
		'slider_btn_txt'                    => esc_html__('Join Club','ultra-gym-pro'),

		//about 
		'about_section_enable'			    => (bool) true,
		'about_content_type'			    => 'post',
		'about_custom_title'				=> esc_html__('Free Membership for Three Months','ultra-gym-pro'),
		'about_section_title'				=> esc_html__('Featured Content','ultra-gym-pro'),
		'about_btn_label'					=> esc_html__('Explore More','ultra-gym-pro'),
		'about_custom_content'				=> esc_html__('When I first started training for marathons a little over ten years ago, my coach told me something I’ve never forgotten: that I would need to learn how to be comfortable with being uncomfortable.','ultra-gym-pro'),

		// Expert
		'expert_section_enable'				=> (bool) true,
		'expert_social_menu_enable'			=> (bool) true,
		'expert_content_type'				=> 'post',
		'expert_column'						=> 'col-3',
		'expert_count'						=> 3,
		'expert_autoplay_enable'			=> (bool) false,
		'expert_subtitle'                   => esc_html__('New Arrivals','ultra-gym-pro'),
		'expert_btn_txt'                    => esc_html__('Join Club','ultra-gym-pro'),
		
		// Slider
		'event_section_enable'				=> (bool) true,
		'event_content_type'				=> 'post',
		'event_count'						=> 3,
		
		//service
		'service_section_enable'		    => (bool) true,
		'service_section_sub_title'			=> esc_html__( 'Our Services', 'ultra-gym-pro' ),
		'service_content_type'			    =>'post',
		'service_posts_count'			    => 3,
		'service_section_title'			    => esc_html__( 'Training & Exercise', 'ultra-gym-pro' ),

		//video 
		'video_section_enable'			    => (bool) true,
		'video_content_type'			    => 'post',
		'video_custom_title'				=> esc_html__('Quarantine Fitness & Healthy Tips copy','ultra-gym-pro'),
		'video_section_title'				=> esc_html__('New Video','ultra-gym-pro'),
		'video_btn_label'					=> esc_html__('Explore More','ultra-gym-pro'),
		'video_custom_content'				=> esc_html__('When I first started training for marathons a little over ten years ago, my coach told me something I’ve never forgotten: that I would need to learn how to be comfortable with being uncomfortable.','ultra-gym-pro'),
		

		//testimonial
        'testimonial_section_enable'        => (bool) true,
		'testimonial_section_sub_title'     => esc_html__('Testimonial','ultra-gym-pro'),
		'testimonial_section_title'	        => esc_html__('Our Happy Clients','ultra-gym-pro'),
		'testimonial_content_type'          =>'post',
		'testimonial_posts_count'           =>4,

		// contact
		'contact_section_enable'			=> (bool) true,
		'contact_section_subtitle'          => esc_html__('Contact','ultra-gym-pro'),
		'contact_section_title'			    => esc_html__( 'Join Us, Be Healthy', 'ultra-gym-pro' ),
		'contact_section_phoneNumber'	    => '+15 000 000 000',
		'contact_section_address'			=> esc_html__( 'Little Rock, United', 'ultra-gym-pro' ),
		'contact_section_email'			    => 'info@ultragym.com',

		// blog
		'blog_section_enable'			    => (bool) true,
		'blog_sub_title'          			=> esc_html__('Blog','ultra-gym-pro'),
		'blog_content_type'				    => 'recent',
		'blog_count'					    => 3,
		'blog_title'					    => esc_html__( 'Amazing Articles', 'ultra-gym-pro' ),
		'blog_post_read_more_btn_label'	    => esc_html__( 'Read More', 'ultra-gym-pro' ),
		'blog_load_more_btn_label'		    => esc_html__( 'Load More', 'ultra-gym-pro' ),

		// Popular Post
		'popular_post_section_enable'		=> (bool) true,
		'popular_post_sub_title'   	=> esc_html__('Popular Post','ultra-gym-pro'),
		'popular_post_content_type'			=> 'recent',
		'popular_post_count'				=> 2,
		'popular_post_title'				=> esc_html__( 'Amazing Articles', 'ultra-gym-pro' ),
		'popular_post_btn_title'			=> esc_html__( 'Continue Reading', 'ultra-gym-pro' ),
		
		// team
		'team_section_enable'			=> true,
		'team_content_type'				=> 'category',
		'team_count'					=> 4,
		'team_column'					=> 'col-4',
		'team_title'					=> esc_html__( 'Meet Our Team', 'ultra-gym-pro' ),
		'team_sub_title'				=> esc_html__( 'Our Team', 'ultra-gym-pro' ),
		'team_btn_title'				=> esc_html__( 'View All Team', 'ultra-gym-pro' ),

		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,

		// Featured Post
		'featured_post_section_enable'		=> true,
		'featured_post_content_type'		=> 'category',
		'featured_post_title'				=> esc_html__( 'GET THE WORLD CLASS & VERIFIED COURSE', 'ultra-gym-pro' ),
		'featured_post_description'			=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'ultra-gym-pro' ),
		'featured_post_count'				=> 3,
		'featured_post_column'				=> 'col-3',

		//cta
		'cta_section_enable' 	=> true,
		'cta_sub_title'			=> 	esc_html__('STARTING FROM', 'ultra-gym-pro'),
		'cta_content_type'		=> 'post',
		'cta_read_more'			=>	esc_html__('Book Now', 'ultra-gym-pro'),
	);

	$output = apply_filters( 'ultragym_pro_default_theme_options', $ultragym_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}