<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'ultragym_pro_about_section', 
    array(
        'title'             => esc_html__( 'About us','ultra-gym-pro' ),
        'description'       => esc_html__( 'About us  Section options.', 'ultra-gym-pro' ),
        'panel'             => 'ultragym_pro_front_page_panel',
        'active_callback'   => function( $control ) {
            return ( 
                ultragym_pro_is_default_layout( $control )
                ||
                ultragym_pro_is_pro_layout( $control )
                ||
                ultragym_pro_is_second_layout( $control )
                ||
                ultragym_pro_is_third_layout( $control )
                ||
                ultragym_pro_is_fourth_layout( $control )
                ||
                ultragym_pro_is_fifth_layout( $control )
            );
        },
    ) 
);

// About content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[about_section_enable]', 
    array(
        'default'			=> 	$options['about_section_enable'],
        'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
    ) 
);

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[about_section_enable]',
    array(
        'label'             => esc_html__( 'About Section Enable', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_about_section',
        'on_off_label' 		=> ultragym_pro_switch_options(),
    ) 
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[about_section_enable]',
        array(
            'selector'            => '#about-us .tooltiptext',
            'settings'            => 'ultragym_pro_theme_options[about_section_enable]',
        ) 
    );
}

// about section title control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[about_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['about_section_title'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('ultragym_pro_theme_options[about_section_title]',
    array(
        'label'             => esc_html__( 'Section Sub Title', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_about_section',
        'type'              =>'text',
        'active_callback'	=> 'ultragym_pro_is_about_section_enable',
    )
);
$wp_customize->selective_refresh->add_partial(
    'ultragym_pro_theme_options[about_section_title]',
    array(
        'selector'            => '#about-us .section-subtitle',
        'render_callback'     => 'ultragym_pro_about_section_partial_title',
    )
);

// About content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[about_content_type]',
    array(
        'default'          	=> $options['about_content_type'],
        'sanitize_callback' => 'ultragym_pro_sanitize_select',
    ) 
);

$wp_customize->add_control( 'ultragym_pro_theme_options[about_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_about_section',
        'type'				=> 'select',
        'active_callback' 	=> 'ultragym_pro_is_about_section_enable',
        'choices'			=> array( 
                'page' 		=> esc_html__( 'Page', 'ultra-gym-pro' ),
                'post' 		=> esc_html__( 'Post', 'ultra-gym-pro' ),
                'category' 	=> esc_html__( 'Category', 'ultra-gym-pro' ),
                'custom' 	=> esc_html__( 'Custom', 'ultra-gym-pro' ),
        ),
    ) 
);

	// about pages drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[about_content_page]', 
        array(
            'sanitize_callback' => 'ultragym_pro_sanitize_page',
        ) 
    );

	$wp_customize->add_control( new UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[about_content_page]',
        array(
            'label'             => esc_html__( 'Select Page', 'ultra-gym-pro' ),
            'section'           => 'ultragym_pro_about_section',
            'choices'			=> ultragym_pro_page_choices(),
            'active_callback'	=> 'ultragym_pro_is_about_section_content_page_enable',
        ) 
    ) );

	// about posts drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[about_content_post]',
        array(
            'sanitize_callback' => 'ultragym_pro_sanitize_page',
        )
    );

	$wp_customize->add_control( new UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[about_content_post]',
        array(
            'label'             => esc_html__( 'Select Post', 'ultra-gym-pro' ),
            'section'           => 'ultragym_pro_about_section',
            'choices'			=> ultragym_pro_post_choices(),
            'active_callback'	=> 'ultragym_pro_is_about_section_content_post_enable',
        )
    ) );


// about posts drop down chooser control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[about_category]', 
    array(
        'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
    )
);

$wp_customize->add_control( new UltraGym_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'ultragym_pro_theme_options[about_category]',
    array(
        'label'             => esc_html__( 'Select Categories', 'ultra-gym-pro' ),
        'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro' ),
        'type'           	=> 'dropdown-taxonomies',
        'section'           => 'ultragym_pro_about_section',
        'active_callback'	=> 'ultragym_pro_is_about_section_content_category_enable',
    )
) ); 

// About title setting
$wp_customize->add_setting('ultragym_pro_theme_options[about_custom_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_custom_title']
    )
);

$wp_customize->add_control('ultragym_pro_theme_options[about_custom_title]',
    array(
        'section'			=> 'ultragym_pro_about_section',
        'label'				=> esc_html__( 'Title:', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'ultragym_pro_if_about_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('ultragym_pro_theme_options[about_custom_title]',
    array(
        'selector'            => '#about-us .section-title',
        'render_callback'     => 'ultragym_pro_about_section_partial_custom_title',
    )
);

// About content setting
$wp_customize->add_setting('ultragym_pro_theme_options[about_custom_content]',
    array(
        'sanitize_callback' => 'sanitize_textarea_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_custom_content']

    )
);

$wp_customize->add_control('ultragym_pro_theme_options[about_custom_content]',
    array(
        'section'			=> 'ultragym_pro_about_section',
        'label'				=> esc_html__( 'Content:', 'ultra-gym-pro' ),
        'type'          	=>'textarea',
        'active_callback'	=> 'ultragym_pro_if_about_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('ultragym_pro_theme_options[about_custom_content]',array(
        'selector'            => '#about-us .section-header span.content',
        'render_callback'     => 'ultragym_pro_about_section_partial_custom_content',
    )
);

// About image setting
$wp_customize->add_setting('ultragym_pro_theme_options[about_custom_image]',
    array(
        'sanitize_callback' => 'ultragym_pro_sanitize_image',
    )
);

$wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize, 'ultragym_pro_theme_options[about_custom_image]',
        array(
            'section'			=> 'ultragym_pro_about_section',
            'label'				=> esc_html__( 'Image:', 'ultra-gym-pro' ),
            'active_callback' 	=> 'ultragym_pro_if_about_section_content_custom_enable',
        )
    )
);

// About content setting
$wp_customize->add_setting('ultragym_pro_theme_options[about_btn_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_btn_label']

    )
);

$wp_customize->add_control('ultragym_pro_theme_options[about_btn_label]',
    array(
        'section'			=> 'ultragym_pro_about_section',
        'label'				=> esc_html__( 'Button Label:', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback'	=> 'ultragym_pro_is_about_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[about_btn_label]',
		array(
			'selector'            => '#about-us div.read-more .btn',
			'settings'            => 'ultragym_pro_theme_options[about_btn_label]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'ultragym_pro_about_btn_label_partial',
		) 
	);
}

$wp_customize->add_setting( 'ultragym_pro_theme_options[about_btn_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'ultragym_pro_theme_options[about_btn_url]',
    array(
        'label'           	=> esc_html__( 'Button URL', 'ultra-gym-pro' ),
        'section'        	=> 'ultragym_pro_about_section',
        'active_callback' 	=> 'ultragym_pro_if_about_section_content_custom_enable',
        'type'				=> 'url',
    ) 
);
