<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage UltraGym Pro
 * @since UltraGym Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'ultragym_pro_blog_section',
    array(
        'title'             => esc_html__( 'Blog','ultra-gym-pro' ),
        'description'       => esc_html__( 'Blog Section options.', 'ultra-gym-pro' ),
        'panel'             => 'ultragym_pro_front_page_panel',
    )
);

// Blog content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[blog_section_enable]',
    array(
        'default'           =>  $options['blog_section_enable'],
        'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[blog_section_enable]',
    array(
        'label'             => esc_html__( 'Blog Section Enable', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_blog_section',
        'on_off_label'      => ultragym_pro_switch_options(),
    ) 
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[blog_section_enable]',
        array(
            'selector'            => '#blog .tooltiptext',
            'settings'            => 'ultragym_pro_theme_options[blog_section_enable]',
        )
    );
}

// Blog section sub title control and setting
$wp_customize->add_setting('ultragym_pro_theme_options[blog_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage',
        'default'  => $options['blog_sub_title'],
    )
);

$wp_customize->add_control('ultragym_pro_theme_options[blog_sub_title]',
    array(
        'label' => esc_html__('Section Sub Title', 'ultra-gym-pro'),
        'section' => 'ultragym_pro_blog_section',
        'type' => 'text',
        'active_callback' => 'ultragym_pro_is_blog_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[blog_sub_title]',
        array(
            'selector'            => '#blog .section-header p.section-subtitle',
            'settings'            => 'ultragym_pro_theme_options[blog_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'ultragym_pro_blog_sub_title_partial',
        )
    );
}

// blog title setting and control
$wp_customize->add_setting( 'ultragym_pro_theme_options[blog_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['blog_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'ultragym_pro_theme_options[blog_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_blog_section',
        'active_callback'   => 'ultragym_pro_is_blog_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[blog_title]',
        array(
            'selector'            => '#blog .section-header h2.section-title',
            'settings'            => 'ultragym_pro_theme_options[blog_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'ultragym_pro_blog_title_partial',
        )
    );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[blog_count]',
    array(
        'default'           => $options['blog_count'],
        'sanitize_callback' => 'ultragym_pro_sanitize_number_range',
        'validate_callback' => 'ultragym_pro_validate_blog_count',
    )
);

$wp_customize->add_control( 'ultragym_pro_theme_options[blog_count]',
    array(
        'label'             => esc_html__( 'Number of Posts', 'ultra-gym-pro' ),
        'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_blog_section',
        'active_callback'   => 'ultragym_pro_is_blog_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 3,
            'max'   => 12,
            'style' => 'width: 100px;'
        ),
    ) 
);

// Blog content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[blog_content_type]',
    array(
        'default'           => $options['blog_content_type'],
        'sanitize_callback' => 'ultragym_pro_sanitize_select',
    ) 
);

$wp_customize->add_control( 'ultragym_pro_theme_options[blog_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_blog_section',
        'type'              => 'select',
        'active_callback'   => 'ultragym_pro_is_blog_section_enable',
        'choices'           => array( 
            'page'      => esc_html__( 'Page', 'ultra-gym-pro' ),
            'post'      => esc_html__( 'Post', 'ultra-gym-pro' ),
            'category'  => esc_html__( 'Category', 'ultra-gym-pro' ),
            'recent'    => esc_html__( 'Recent', 'ultra-gym-pro' ),
        ),
    ) 
);

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :

    // blog pages drop down chooser control and setting
    $wp_customize->add_setting( 'ultragym_pro_theme_options[blog_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'ultragym_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[blog_content_page_' . $i . ']', 
        array(
            'label'             => sprintf( esc_html__( 'Select Page %d', 'ultra-gym-pro' ), $i ),
            'section'           => 'ultragym_pro_blog_section',
            'choices'           => ultragym_pro_page_choices(),
            'active_callback'   => 'ultragym_pro_is_blog_section_content_page_enable',
        )
    ) );

    // blog posts drop down chooser control and setting
    $wp_customize->add_setting( 'ultragym_pro_theme_options[blog_content_post_' . $i . ']', 
        array(
            'sanitize_callback' => 'ultragym_pro_sanitize_page',
        ) 
    );

    $wp_customize->add_control( new UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[blog_content_post_' . $i . ']', 
        array(
            'label'             => sprintf( esc_html__( 'Select Post %d', 'ultra-gym-pro' ), $i ),
            'section'           => 'ultragym_pro_blog_section',
            'choices'           => ultragym_pro_post_choices(),
            'active_callback'   => 'ultragym_pro_is_blog_section_content_post_enable',
        ) 
    ) );

    //blog separator
    $wp_customize->add_setting('ultragym_pro_theme_options[blog_separator'. $i .']',
        array(
            'sanitize_callback'      => 'ultragym_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new UltraGym_Pro_Customize_Horizontal_Line($wp_customize,'ultragym_pro_theme_options[blog_separator'. $i .']',
        array(
            'active_callback'       => 'ultragym_pro_is_blog_section_separator_enable',
            'type'                  => 'hr',
            'section'               => 'ultragym_pro_blog_section',
        )
    ));

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'ultragym_pro_theme_options[blog_content_category]',
    array(
        'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
    )
) ;

$wp_customize->add_control( new UltraGym_Pro_Dropdown_Taxonomies_Control( $wp_customize,'ultragym_pro_theme_options[blog_content_category]',
    array(
        'label'             => esc_html__( 'Select Category', 'ultra-gym-pro' ),
        'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_blog_section',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'ultragym_pro_is_blog_section_content_category_enable'
    ) 
) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'ultragym_pro_theme_options[blog_category_exclude]',
    array(
        'sanitize_callback' => 'ultragym_pro_sanitize_category_list',
    )
) ;

$wp_customize->add_control( new UltraGym_Pro_Dropdown_Multiple_Chooser( $wp_customize,'ultragym_pro_theme_options[blog_category_exclude]', 
    array(
        'label'             => esc_html__( 'Select Excluding Categories', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_blog_section',
        'type'              => 'dropdown_multiple_chooser',
        'choices'           =>  ultragym_pro_category_choices(),
        'active_callback'   => 'ultragym_pro_is_blog_section_content_recent_enable'
    )
) );

if($options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' ||  $options['home_layout'] == 'pro-design'){

    // Blog content setting
    $wp_customize->add_setting('ultragym_pro_theme_options[blog_post_read_more_btn_label]',
        array(
            'sanitize_callback' => 'sanitize_text_field',
            'transport'			=> 'postMessage',
            'default'           => $options['blog_post_read_more_btn_label']
    
        )
    );
    
    $wp_customize->add_control('ultragym_pro_theme_options[blog_post_read_more_btn_label]',
        array(
            'section'			=> 'ultragym_pro_blog_section',
            'label'				=> esc_html__( 'Post Read More Button Label', 'ultra-gym-pro' ),
            'type'          	=>'text',
            'active_callback'	=> 'ultragym_pro_is_blog_section_enable'
        )
    );
    
    
    // Abort if selective refresh is not available.
    if ( isset( $wp_customize->selective_refresh ) ) {
        $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[blog_post_read_more_btn_label]',
            array(
                'selector'            => '#blog div.more-link a',
                'settings'            => 'ultragym_pro_theme_options[blog_post_read_more_btn_label]',
                'fallback_refresh'    => true,
                'container_inclusive' => false,
                'render_callback'     => 'ultragym_pro_blog_post_read_more_btn_label_partial',
            ) 
        );
    }
    
    // Blog content setting
    $wp_customize->add_setting('ultragym_pro_theme_options[blog_load_more_btn_label]',
        array(
            'sanitize_callback' => 'sanitize_text_field',
            'transport'			=> 'postMessage',
            'default'           => $options['blog_load_more_btn_label']
    
        )
    );
    
    $wp_customize->add_control('ultragym_pro_theme_options[blog_load_more_btn_label]',
        array(
            'section'			=> 'ultragym_pro_blog_section',
            'label'				=> esc_html__( 'Load More Button Label', 'ultra-gym-pro' ),
            'type'          	=>'text',
            'active_callback'	=> 'ultragym_pro_is_blog_section_enable'
        )
    );
    
    
    // Abort if selective refresh is not available.
    if ( isset( $wp_customize->selective_refresh ) ) {
        $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[blog_load_more_btn_label]',
            array(
                'selector'            => '#blog div.read-more a.btn',
                'settings'            => 'ultragym_pro_theme_options[blog_load_more_btn_label]',
                'fallback_refresh'    => true,
                'container_inclusive' => false,
                'render_callback'     => 'ultragym_pro_blog_load_more_btn_label_partial',
            ) 
        );
    }
    
    $wp_customize->add_setting( 'ultragym_pro_theme_options[blog_load_more_btn_url]',
        array(
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    
    $wp_customize->add_control( 'ultragym_pro_theme_options[blog_load_more_btn_url]',
        array(
            'label'           	=> esc_html__( 'Load More Button URL', 'ultra-gym-pro' ),
            'section'        	=> 'ultragym_pro_blog_section',
            'active_callback' 	=> 'ultragym_pro_is_blog_section_enable',
            'type'				=> 'url',
        ) 
    );
    
}
