<?php
/**
 * Contact Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'ultragym_pro_contact_section', 
    array(
        'title'             => esc_html__( 'Contact us','ultra-gym-pro' ),
        'description'       => esc_html__( 'Contact us  Section options.', 'ultra-gym-pro' ),
        'panel'             => 'ultragym_pro_front_page_panel',
        'active_callback'   => function( $control ) {
            return ( 
                ultragym_pro_is_default_layout( $control )
                ||
                ultragym_pro_is_pro_layout( $control )
                ||
                ultragym_pro_is_second_layout( $control )
            );
        },
    ) 
);

// Contact content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[contact_section_enable]', 
    array(
        'default'			=> 	$options['contact_section_enable'],
        'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
    ) 
);

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[contact_section_enable]',
    array(
        'label'             => esc_html__( 'Contact Section Enable', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_contact_section',
        'on_off_label' 		=> ultragym_pro_switch_options(),
    ) 
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[contact_section_enable]',
        array(
            'selector'            => '#contact .tooltiptext',
            'settings'            => 'ultragym_pro_theme_options[contact_section_enable]',
        ) 
    ); 
}

// contact section title control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[contact_section_subtitle]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['contact_section_subtitle'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('ultragym_pro_theme_options[contact_section_subtitle]',
    array(
        'label'             => esc_html__( 'Section Sub Title', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'ultragym_pro_is_contact_section_enable',
    )
);
$wp_customize->selective_refresh->add_partial(
    'ultragym_pro_theme_options[contact_section_subtitle]',
    array(
        'selector'            => '#contact .section-subtitle',
        'render_callback'     => 'ultragym_pro_contact_section_partial_title',
    )
);

// contact section title control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[contact_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['contact_section_title'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('ultragym_pro_theme_options[contact_section_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'ultragym_pro_is_contact_section_enable',
    )
);
$wp_customize->selective_refresh->add_partial(
    'ultragym_pro_theme_options[contact_section_title]',
    array(
        'selector'            => '#contact .section-title',
        'render_callback'     => 'ultragym_pro_contact_section_partial_title',
    )
);

// contact section title control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[contact_section_shortcode]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=>'refresh'
    ) 
);

$wp_customize->add_control('ultragym_pro_theme_options[contact_section_shortcode]',
    array(
        'label'             => esc_html__( 'Contact Shortcode', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'ultragym_pro_is_contact_section_enable',
    )
);

if($options['home_layout'] == 'default-design' || $options['home_layout'] == 'pro-design'){

    // contact section title control and setting
    $wp_customize->add_setting( 'ultragym_pro_theme_options[contact_map_shortcode]',
        array(
            'sanitize_callback' => 'sanitize_text_field',
            'transport'			=>'refresh'
        ) 
    );
    
    $wp_customize->add_control('ultragym_pro_theme_options[contact_map_shortcode]',
        array(
            'label'             => esc_html__( 'Map Shortcode', 'ultra-gym-pro' ),
            'section'           => 'ultragym_pro_contact_section',
            'type'              => 'text',
            'active_callback'	=> 'ultragym_pro_is_contact_section_enable',
        )
    );
}

//contact_section_phoneNumber
$wp_customize->add_setting('ultragym_pro_theme_options[contact_section_phoneNumber]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['contact_section_phoneNumber'],
    )
);

$wp_customize->add_control('ultragym_pro_theme_options[contact_section_phoneNumber]',
    array(
        'section'			=> 'ultragym_pro_contact_section',
        'label'				=> esc_html__( 'Contact Number:', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'ultragym_pro_is_contact_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[contact_section_phoneNumber]',
		array(
			'selector'            => '#contact div.contact-address div.phone-number span a',
			'settings'            => 'ultragym_pro_theme_options[contact_section_phoneNumber]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'ultragym_pro_contact_section_phoneNumber_partial',
		) 
	);
}

//contact_section_address
$wp_customize->add_setting('ultragym_pro_theme_options[contact_section_address]',
array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['contact_section_address'],
    )
);

$wp_customize->add_control('ultragym_pro_theme_options[contact_section_address]',
    array(
        'section'			=> 'ultragym_pro_contact_section',
        'label'				=> esc_html__( 'Address:', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'ultragym_pro_is_contact_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[contact_section_address]',
		array(
            'selector'            => '#contact div.contact-address div.address span',
			'settings'            => 'ultragym_pro_theme_options[contact_section_address]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'ultragym_pro_contact_section_address_partial',
            ) 
        );
    }

//contact_section_email
$wp_customize->add_setting('ultragym_pro_theme_options[contact_section_email]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['contact_section_email'],
    )
);

$wp_customize->add_control('ultragym_pro_theme_options[contact_section_email]',
    array(
        'section'			=> 'ultragym_pro_contact_section',
        'label'				=> esc_html__( 'E-mail:', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'ultragym_pro_is_contact_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[contact_section_email]',
        array(
            'selector'            => '#contact div.contact-address div.mail span a',
            'settings'            => 'ultragym_pro_theme_options[contact_section_email]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'ultragym_pro_contact_section_email_partial',
        ) 
    );
}