<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add cta section
$wp_customize->add_section( 'ultragym_pro_cta_section', array(
	'title'             => esc_html__( 'Call To Action','ultra-gym-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'ultra-gym-pro' ),
	'panel'             => 'ultragym_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            ultragym_pro_is_default_layout( $control )
            ||
            ultragym_pro_is_fifth_layout( $control )
        );
    },

) );

// cta content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_cta_section',
	'on_off_label' 		=> ultragym_pro_switch_options(),
) ) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[cta_section_enable]', array(
		'selector'            => '#cta .tooltiptext',
		'settings'            => 'ultragym_pro_theme_options[cta_section_enable]',
    ) );
}

// cta sub title control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[cta_sub_title]', array(
    'default'           => $options['cta_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[cta_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'ultra-gym-pro' ),
	'section'        	=> 'ultragym_pro_cta_section',
	'active_callback' 	=> 'ultragym_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[cta_sub_title]', array(
		'selector'            => '#cta .section-header span.section-subtitle',
		'settings'            => 'ultragym_pro_theme_options[cta_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'ultragym_pro_cta_sub_title_partial',
    ) );
}

// cta content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[cta_content_type]', array(
    'default'          	=> $options['cta_content_type'],
    'sanitize_callback' => 'ultragym_pro_sanitize_select',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[cta_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
    'section'           => 'ultragym_pro_cta_section',
    'type'				=> 'select',
    'active_callback' 	=> 'ultragym_pro_is_cta_section_enable',
    'choices'			=> ultragym_pro_cta_content_type(),
) );

$wp_customize->add_setting( 'ultragym_pro_theme_options[cta_content_page]', array(
    'sanitize_callback' => 'ultragym_pro_sanitize_page',
) );

$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[cta_content_page]', array(
    'label'             => esc_html__( 'Select Page', 'ultra-gym-pro' ),
    'section'           => 'ultragym_pro_cta_section',
    'choices'			=> ultragym_pro_page_choices(),
    'active_callback'	=> 'ultragym_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[cta_content_post]', array(
    'sanitize_callback' => 'ultragym_pro_sanitize_page',
) );

$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[cta_content_post]', array(
    'label'             => esc_html__( 'Select posts', 'ultra-gym-pro' ),
    'section'           => 'ultragym_pro_cta_section',
    'choices'			=> ultragym_pro_post_choices(),
    'active_callback'	=> 'ultragym_pro_is_cta_section_content_post_enable',
) ) );



// cta read more setting and control
$wp_customize->add_setting( 'ultragym_pro_theme_options[cta_read_more]', array(
	'default'			=> $options['cta_read_more'],
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         =>'postMessage',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[cta_read_more]', array(
	'label'           	=> esc_html__( 'Read More Text', 'ultra-gym-pro' ),
	'section'        	=> 'ultragym_pro_cta_section',
	'active_callback' 	=> 'ultragym_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[cta_read_more]', array(
		'selector'            => '#cta .wrapper .read-more a.btn',
		'settings'            => 'ultragym_pro_theme_options[cta_read_more]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'ultragym_pro_cta_read_more_partial',
    ) );
}
