<?php
/**
 * Expert Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add Expert section
$wp_customize->add_section( 'ultragym_pro_expert_section', array(
	'title'             => esc_html__( 'Expert','ultra-gym-pro' ),
	'description'       => esc_html__( 'Expert Section options.', 'ultra-gym-pro' ),
	'panel'             => 'ultragym_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            ultragym_pro_is_default_layout( $control )
            ||
            ultragym_pro_is_pro_layout( $control )
        );
    },
) );

// Expert content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[expert_section_enable]', 
	array(
		'default'			=> 	$options['expert_section_enable'],
		'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[expert_section_enable]',
	array(
		'label'             => esc_html__( 'Expert Section Enable', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_expert_section',
		'on_off_label' 		=> ultragym_pro_switch_options(),
	)
) );
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[expert_section_enable]', 
		array(
			'selector'            => '#expert .tooltiptext',
			'settings'            => 'ultragym_pro_theme_options[expert_section_enable]',
		) 
	);
}
// expert content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[expert_column]', array(
	'default'          	=> $options['expert_column'],
	'sanitize_callback' => 'ultragym_pro_sanitize_select',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[expert_column]', array(
	'label'             => esc_html__( 'Column Layout', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_expert_section',
	'type'				=> 'select',
	'active_callback' 	=> 'ultragym_pro_is_expert_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'ultra-gym-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'ultra-gym-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'ultra-gym-pro' ),
	),
) );

// Expert number control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[expert_count]',
	array(
		'default'          	=> $options['expert_count'],
		'sanitize_callback' => 'ultragym_pro_sanitize_number_range',
		'validate_callback' => 'ultragym_pro_validate_expert_count',
	)
);

$wp_customize->add_control( 'ultragym_pro_theme_options[expert_count]',
	array(
		'label'             => esc_html__( 'Number of Featured', 'ultra-gym-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_expert_section',
		'active_callback'   => 'ultragym_pro_is_expert_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 12,
			'style' => 'width: 100px;'
			),
	)
);

// Expert content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[expert_content_type]',
	array(
		'default'          	=> $options['expert_content_type'],
		'sanitize_callback' => 'ultragym_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'ultragym_pro_theme_options[expert_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_expert_section',
		'type'				=> 'select',
		'active_callback' 	=> 'ultragym_pro_is_expert_section_enable',
		'choices'			=> array( 
				'page' 		=> esc_html__( 'Page', 'ultra-gym-pro' ),
				'post' 		=> esc_html__( 'Post', 'ultra-gym-pro' ),
				'category' 	=> esc_html__( 'Category', 'ultra-gym-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['expert_count']; $i++ ) :

		
	//expert_btn_txt
	$wp_customize->add_setting('ultragym_pro_theme_options[expert_subtitle_'.$i.']',
		array(
			'default'           => $options['expert_subtitle'],
			'sanitize_callback' => 'sanitize_text_field',
			'transport'			=> 'refresh',
		)
	);

	$wp_customize->add_control('ultragym_pro_theme_options[expert_subtitle_'.$i.']',
		array(
			'section'			=> 'ultragym_pro_expert_section',
			'label'             => sprintf(esc_html__( 'Subtitle: %d', 'ultra-gym-pro'), $i ),
			'type'          	=> 'text',
			'active_callback' 	=> 'ultragym_pro_is_expert_section_enable'
		)
	);


	// expert pages drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[expert_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'ultragym_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[expert_content_page_'. $i .']', 
	array(
		'label'             => sprintf(esc_html__( 'Select Page: %d', 'ultra-gym-pro'), $i ),
		'section'           => 'ultragym_pro_expert_section',
		'choices'			=> ultragym_pro_page_choices(),
		'active_callback'	=> 'ultragym_pro_is_expert_section_content_page_enable',
	)
	) );

	// expert posts drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[expert_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'ultragym_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[expert_content_post_'. $i .']',
		array(
			'label'             => sprintf(esc_html__( 'Select Post : %d', 'ultra-gym-pro'), $i ),
			'section'           => 'ultragym_pro_expert_section',
			'choices'			=> ultragym_pro_post_choices(),
			'active_callback'	=> 'ultragym_pro_is_expert_section_content_post_enable',
		)
	) );

	// UltraGym_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('ultragym_pro_theme_options[expert_separator'. $i .']',
		array(
		'sanitize_callback'      => 'ultragym_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new  UltraGym_Pro_Customize_Horizontal_Line($wp_customize,'ultragym_pro_theme_options[expert_separator'. $i .']',
		array(
			'active_callback'       => 'ultragym_pro_is_expert_section_separator_enable',
			'type'                  =>'hr',
			'section'               =>'ultragym_pro_expert_section',
		)
	));

endfor;

// expert posts drop down chooser control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[expert_category]',
	array(
		'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'ultragym_pro_theme_options[expert_category]', 
	array(
		'label'             => esc_html__( 'Select Categories', 'ultra-gym-pro' ),
		'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro' ),
		'type'           	=> 'dropdown-taxonomies',
		'section'           => 'ultragym_pro_expert_section',
		'active_callback'	=> 'ultragym_pro_is_expert_section_content_category_enable',
	)
 ) ); 


//expert_btn_txt
$wp_customize->add_setting('ultragym_pro_theme_options[expert_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['expert_btn_txt'],
    )
);

$wp_customize->add_control('ultragym_pro_theme_options[expert_btn_txt]',
    array(
        'section'			=> 'ultragym_pro_expert_section',
        'label'				=> esc_html__( 'Button Text:', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'ultragym_pro_is_expert_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[expert_btn_txt]',
		array(
			'selector'            => '#expert article div.read-more a.btn',
			'settings'            => 'ultragym_pro_theme_options[expert_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'ultragym_pro_expert_btn_txt_partial',
		) 
	);
}
