<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'ultragym_pro_featured_post_section', array(
	'title'             => esc_html__( 'Features','ultra-gym-pro' ),
	'description'       => esc_html__( 'Features Section options.', 'ultra-gym-pro' ),
	'panel'             => 'ultragym_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            ultragym_pro_is_default_layout( $control )
            ||
            ultragym_pro_is_sixth_layout( $control )
        );
    },
) );

// Service content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[featured_post_section_enable]', array(
	'default'			=> 	$options['featured_post_section_enable'],
	'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[featured_post_section_enable]', array(
	'label'             => esc_html__( 'Features Section Enable', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_featured_post_section',
	'on_off_label' 		=> ultragym_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[featured_post_section_enable]', array(
		'selector'            => '#blog-featured-posts .tooltiptext',
		'settings'            => 'ultragym_pro_theme_options[featured_post_section_enable]',
    ) );
}

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[featured_post_description]', array(
		'selector'            => '#business-services p.business-section-subtitle',
		'settings'            => 'ultragym_pro_theme_options[featured_post_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'ultragym_pro_featured_post_description_partial',
    ) );
}

// featured_post content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[featured_post_column]', array(
	'default'          	=> $options['featured_post_column'],
	'sanitize_callback' => 'ultragym_pro_sanitize_select',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[featured_post_column]', array(
	'label'             => esc_html__( 'Column Layout', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_featured_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'ultragym_pro_is_featured_post_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'ultra-gym-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'ultra-gym-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'ultra-gym-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[featured_post_count]', array(
	'default'          	=> $options['featured_post_count'],
	'sanitize_callback' => 'ultragym_pro_sanitize_number_range',
	'validate_callback' => 'ultragym_pro_validate_featured_post_count',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[featured_post_count]', array(
	'label'             => esc_html__( 'Number of Features', 'ultra-gym-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_featured_post_section',
	'active_callback'   => 'ultragym_pro_is_featured_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

// Service content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[featured_post_content_type]', array(
	'default'          	=> $options['featured_post_content_type'],
	'sanitize_callback' => 'ultragym_pro_sanitize_select',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[featured_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_featured_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'ultragym_pro_is_featured_post_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'ultra-gym-pro' ),
		'post' 		=> esc_html__( 'Post', 'ultra-gym-pro' ),
		'category' 	=> esc_html__( 'Category', 'ultra-gym-pro' ),
	),
) );

for ( $i = 1; $i <= $options['featured_post_count']; $i++ ) :

	// featured_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[featured_post_content_page_' . $i . ']', array(
		'sanitize_callback' => 'ultragym_pro_sanitize_page',
	) );

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[featured_post_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'ultra-gym-pro' ), $i ),
		'section'           => 'ultragym_pro_featured_post_section',
		'choices'			=> ultragym_pro_page_choices(),
		'active_callback'	=> 'ultragym_pro_is_featured_post_section_content_page_enable',
	) ) );

	// featured_post posts drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[featured_post_content_post_' . $i . ']', array(
		'sanitize_callback' => 'ultragym_pro_sanitize_page',
	) );

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[featured_post_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'ultra-gym-pro' ), $i ),
		'section'           => 'ultragym_pro_featured_post_section',
		'choices'			=> ultragym_pro_post_choices(),
		'active_callback'	=> 'ultragym_pro_is_featured_post_section_content_post_enable',
	) ) );

	// featured_post hr setting and control
	$wp_customize->add_setting( 'ultragym_pro_theme_options[featured_post_hr_'. $i .']', array(
		'sanitize_callback' => 'ultragym_pro_sanitize_html'
	) );

	$wp_customize->add_control( new  UltraGym_Pro_Customize_Horizontal_Line( $wp_customize, 'ultragym_pro_theme_options[featured_post_hr_'. $i .']',
		array(
			'section'         => 'ultragym_pro_featured_post_section',
			'active_callback' => 'ultragym_pro_is_featured_post_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'ultragym_pro_theme_options[featured_post_content_category]', array(
	'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Taxonomies_Control( $wp_customize,'ultragym_pro_theme_options[featured_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'ultra-gym-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_featured_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'ultragym_pro_is_featured_post_section_content_category_enable'
) ) );
