<?php
/**
 * Popular Posts Section options
 *
 * @package Theme Palace
 * @subpackage UltraGym Pro
 * @since UltraGym Pro 1.0.0
 */

// Add Popular Posts section
$wp_customize->add_section( 'ultragym_pro_popular_post_section',
    array(
        'title'             => esc_html__( 'Popular Posts','ultra-gym-pro' ),
        'description'       => esc_html__( 'Popular Posts Section options.', 'ultra-gym-pro' ),
        'panel'             => 'ultragym_pro_front_page_panel',
        'active_callback'   => function( $control ) {
            return ( 
                ultragym_pro_is_default_layout( $control )
                ||
                ultragym_pro_is_sixth_layout( $control )
            );
        },
    )
);

// Popular Posts content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[popular_post_section_enable]',
    array(
        'default'           =>  $options['popular_post_section_enable'],
        'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[popular_post_section_enable]',
    array(
        'label'             => esc_html__( 'Popular Posts Section Enable', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_popular_post_section',
        'on_off_label'      => ultragym_pro_switch_options(),
    )
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[popular_post_section_enable]',
        array(
            'selector'            => '#blog-latest-posts .tooltiptext',
            'settings'            => 'ultragym_pro_theme_options[popular_post_section_enable]',
        ) 
    );
}

// Popular Posts section sub title control and setting
$wp_customize->add_setting('ultragym_pro_theme_options[popular_post_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage',
        'default'  => $options['popular_post_sub_title'],
    )
);

$wp_customize->add_control('ultragym_pro_theme_options[popular_post_sub_title]',
    array(
        'label' => esc_html__('Section Sub Title', 'ultra-gym-pro'),
        'section' => 'ultragym_pro_popular_post_section',
        'type' => 'text',
        'active_callback' => 'ultragym_pro_is_popular_post_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[popular_post_sub_title]',
        array(
            'selector'            => '#blog-latest-posts .section-header p',
            'settings'            => 'ultragym_pro_theme_options[popular_post_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'ultragym_pro_popular_post_sub_title_partial',
        ) 
    );
}

// popular_post title setting and control
$wp_customize->add_setting( 'ultragym_pro_theme_options[popular_post_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['popular_post_title'],
        'transport'         => 'postMessage',
    ) 
);

$wp_customize->add_control( 'ultragym_pro_theme_options[popular_post_title]',
    array(
        'label'             => esc_html__( 'Title', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_popular_post_section',
        'active_callback'   => 'ultragym_pro_is_popular_post_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[popular_post_title]',
        array(
            'selector'            => '#blog-latest-posts .section-header h2',
            'settings'            => 'ultragym_pro_theme_options[popular_post_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'ultragym_pro_popular_post_title_partial',
        ) 
    );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[popular_post_count]',
    array(
        'default'           => $options['popular_post_count'],
        'sanitize_callback' => 'ultragym_pro_sanitize_number_range',
        'validate_callback' => 'ultragym_pro_validate_popular_post_count',
    ) 
);

$wp_customize->add_control( 'ultragym_pro_theme_options[popular_post_count]',
    array(
        'label'             => esc_html__( 'Number of Posts', 'ultra-gym-pro' ),
        'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_popular_post_section',
        'active_callback'   => 'ultragym_pro_is_popular_post_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 1,
            'max'   => 10,
            'style' => 'width: 100px;'
            ),
    ) 
);

// Popular Posts content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[popular_post_content_type]',
    array(
        'default'           => $options['popular_post_content_type'],
        'sanitize_callback' => 'ultragym_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'ultragym_pro_theme_options[popular_post_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_popular_post_section',
        'type'              => 'select',
        'active_callback'   => 'ultragym_pro_is_popular_post_section_enable',
        'choices'           => array( 
                'page'      => esc_html__( 'Page', 'ultra-gym-pro' ),
                'post'      => esc_html__( 'Post', 'ultra-gym-pro' ),
                'category'  => esc_html__( 'Category', 'ultra-gym-pro' ),
                'recent'    => esc_html__( 'Recent', 'ultra-gym-pro' ),
        ),
    ) 
);

for ( $i = 1; $i <= $options['popular_post_count']; $i++ ) :

    // popular_post pages drop down chooser control and setting
    $wp_customize->add_setting( 'ultragym_pro_theme_options[popular_post_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'ultragym_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[popular_post_content_page_' . $i . ']',
        array(
            'label'             => sprintf( esc_html__( 'Select Page %d', 'ultra-gym-pro' ), $i ),
            'section'           => 'ultragym_pro_popular_post_section',
            'choices'           => ultragym_pro_page_choices(),
            'active_callback'   => 'ultragym_pro_is_popular_post_section_content_page_enable',
        )
    ));

    // popular_post posts drop down chooser control and setting
    $wp_customize->add_setting( 'ultragym_pro_theme_options[popular_post_content_post_' . $i . ']',
        array(
            'sanitize_callback' => 'ultragym_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[popular_post_content_post_' . $i . ']',
        array(
            'label'             => sprintf( esc_html__( 'Select Post %d', 'ultra-gym-pro' ), $i ),
            'section'           => 'ultragym_pro_popular_post_section',
            'choices'           => ultragym_pro_post_choices(),
            'active_callback'   => 'ultragym_pro_is_popular_post_section_content_post_enable',
        ) 
    ));

    //popular_post separator
    $wp_customize->add_setting('ultragym_pro_theme_options[popular_post_separator'. $i .']',
        array(
            'sanitize_callback'      => 'ultragym_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new UltraGym_Pro_Customize_Horizontal_Line($wp_customize,'ultragym_pro_theme_options[popular_post_separator'. $i .']',
        array(
            'active_callback'       => 'ultragym_pro_is_popular_post_section_separator_enable',
            'type'                  =>'hr',
            'section'               =>'ultragym_pro_popular_post_section',
        )
    ));

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'ultragym_pro_theme_options[popular_post_content_category]',
    array(
        'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
    )
);

$wp_customize->add_control( new UltraGym_Pro_Dropdown_Taxonomies_Control( $wp_customize,'ultragym_pro_theme_options[popular_post_content_category]',
    array(
        'label'             => esc_html__( 'Select Category', 'ultra-gym-pro' ),
        'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_popular_post_section',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'ultragym_pro_is_popular_post_section_content_category_enable'
    ) 
));

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'ultragym_pro_theme_options[popular_post_category_exclude]',
    array(
        'sanitize_callback' => 'ultragym_pro_sanitize_category_list',
    )
);

$wp_customize->add_control( new UltraGym_Pro_Dropdown_Multiple_Chooser( $wp_customize,'ultragym_pro_theme_options[popular_post_category_exclude]',
    array(
        'label'             => esc_html__( 'Select Excluding Categories', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_popular_post_section',
        'type'              => 'dropdown_multiple_chooser',
        'choices'           =>  ultragym_pro_category_choices(),
        'active_callback'   => 'ultragym_pro_is_popular_post_section_content_recent_enable'
    ) 
) );


// Blog content setting
$wp_customize->add_setting('ultragym_pro_theme_options[popular_post_btn_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['popular_post_btn_title']

    )
);

$wp_customize->add_control('ultragym_pro_theme_options[popular_post_btn_title]',
    array(
        'section'			=> 'ultragym_pro_popular_post_section',
        'label'				=> esc_html__( 'Read More Button Label', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback'	=> 'ultragym_pro_is_popular_post_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[popular_post_btn_title]',
        array(
            'selector'            => '#blog-latest-posts div.read-more a',
            'settings'            => 'ultragym_pro_theme_options[popular_post_btn_title]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'ultragym_pro_popular_post_btn_title_partial',
        ) 
    );
}