<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'ultragym_pro_service_section', 
	array(
		'title'             => esc_html__( 'Services','ultra-gym-pro' ),
		'description'       => esc_html__( 'Services Section options.', 'ultra-gym-pro' ),
		'panel'             => 'ultragym_pro_front_page_panel',
		'active_callback'   => function( $control ) {
            return ( 
                ultragym_pro_is_default_layout( $control )
                ||
                ultragym_pro_is_pro_layout( $control )
                ||
                ultragym_pro_is_second_layout( $control )
                ||
                ultragym_pro_is_third_layout( $control )
                ||
                ultragym_pro_is_fourth_layout( $control )
                ||
                ultragym_pro_is_fifth_layout( $control )
            );
        },
	) 
);

// Service content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[service_section_enable]', 
	array(
		'default'			=> 	$options['service_section_enable'],
		'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[service_section_enable]', 
	array(
		'label'             => esc_html__( 'Service Section Enable', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_service_section',
		'on_off_label' 		=> ultragym_pro_switch_options(),
	) 
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[service_section_enable]', 
		array(
			'selector'            => '#our-services .tooltiptext',
			'settings'            => 'ultragym_pro_theme_options[service_section_enable]',
		) 
	);
}

// Service section sub title control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[service_section_sub_title]', 
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'postMessage',
		'default'           => $options['service_section_sub_title'],
	) 
);

$wp_customize->add_control('ultragym_pro_theme_options[service_section_sub_title]', 
	array(
		'label'             => esc_html__( 'Section Sub Title', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_service_section',
		'type'              =>'text',
		'active_callback'	=> 'ultragym_pro_is_service_section_enable',
	)
);
$wp_customize->selective_refresh->add_partial('ultragym_pro_theme_options[service_section_sub_title]',
    array(
        'selector'            => '#our-services .section-subtitle',
        'render_callback'     => 'ultragym_pro_service_section_partial_sub_title',
    )
);

// Service section title control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[service_section_title]', 
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'postMessage',
		'default'           => $options['service_section_title'],
		
	) 
);

$wp_customize->add_control('ultragym_pro_theme_options[service_section_title]', 
	array(
		'label'             => esc_html__( 'Section Title', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_service_section',
		'type'              =>'text',
		'active_callback'	=> 'ultragym_pro_is_service_section_enable',
	)
);
$wp_customize->selective_refresh->add_partial(
    'ultragym_pro_theme_options[service_section_title]',
    array(
        'selector'            => '#our-services .section-title',
        'render_callback'     => 'ultragym_pro_service_section_partial_title',
    )
);

// Service content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[service_content_type]',
	array(
		'default'          	=> $options['service_content_type'],
		'sanitize_callback' => 'ultragym_pro_sanitize_select',
	) 
);

$wp_customize->add_control( 'ultragym_pro_theme_options[service_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_service_section',
		'type'				=> 'select',
		'active_callback' 	=> 'ultragym_pro_is_service_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'ultra-gym-pro' ),
			'post' 		=> esc_html__( 'Post', 'ultra-gym-pro' ),
			'category' 	=> esc_html__( 'Category', 'ultra-gym-pro' ),
		),
	) 
);

// Services post number control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[service_posts_count]', 
	array(
		'default'          	=> $options['service_posts_count'],
		'sanitize_callback' => 'ultragym_pro_sanitize_number_range',
		'validate_callback' => 'ultragym_pro_validate_service_posts_count',
	)
);

$wp_customize->add_control( 'ultragym_pro_theme_options[service_posts_count]', 
	array(
		'label'             => esc_html__( 'Number of Posts', 'ultra-gym-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_service_section',
		'active_callback'   => 'ultragym_pro_is_service_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
				'min'	=> 3,
				'max'	=> 6,
				'style' => 'width: 100px;'
			),
	) 
);

for($i = 1; $i <= $options['service_posts_count']; $i ++):

	
    $wp_customize->add_setting( 'ultragym_pro_theme_options[service_icon_' . $i . ']', 
        array(
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

	$wp_customize->add_control( new UltraGym_Pro_Icon_Picker( $wp_customize, 'ultragym_pro_theme_options[service_icon_' . $i . ']',
        array(
            'label'             => sprintf( esc_html__( 'Service Icon %d', 'ultra-gym-pro' ), $i ),
            'section'           => 'ultragym_pro_service_section',
            'active_callback'	=> 'ultragym_pro_is_service_section_enable',
        )
    ) );

    // service pages drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[service_content_page_'.$i.']',
		array(
			'sanitize_callback' => 'ultragym_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[service_content_page_'.$i.']',
		array(
			'label'             => sprintf(esc_html__( 'Select Page : %d', 'ultra-gym-pro'), $i ),
			'section'           => 'ultragym_pro_service_section',
			'choices'			=> ultragym_pro_page_choices(),
			'active_callback'	=> 'ultragym_pro_is_service_section_content_page_enable',
		) 
	) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[service_content_post_'.$i.']', 
		array(
			'sanitize_callback' => 'ultragym_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[service_content_post_'.$i.']', 
		array(
			'label'             => sprintf(esc_html__( 'Select Post : %d', 'ultra-gym-pro'), $i ),
			'section'           => 'ultragym_pro_service_section',
			'choices'			=> ultragym_pro_post_choices(),
			'active_callback'	=> 'ultragym_pro_is_service_section_content_post_enable',
		)
	) );

    // UltraGym_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('ultragym_pro_theme_options[service_separator'. $i .']',
		array(
			'sanitize_callback'      => 'ultragym_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new  UltraGym_Pro_Customize_Horizontal_Line($wp_customize,'ultragym_pro_theme_options[service_separator'. $i .']',
		array(
			'active_callback'       => 'ultragym_pro_is_service_section_separator_enable',
			'type'                  =>'hr',
			'section'               =>'ultragym_pro_service_section',
		)
	));

endfor;

// service category drop down chooser control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[service_category]', 
	array(
		'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'ultragym_pro_theme_options[service_category]',
	array(
		'label'             => esc_html__( 'Select Categories', 'ultra-gym-pro' ),
		'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro' ),
		'type'           	=> 'dropdown-taxonomies',
		'section'           => 'ultragym_pro_service_section',
		'active_callback'	=> 'ultragym_pro_is_service_section_content_category_enable',
	) 
) );

if($options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' ||$options['home_layout'] == 'pro-design'){

	$wp_customize->add_setting( 'ultragym_pro_theme_options[service_bg_image]', 
		array(
			'sanitize_callback' => 'ultragym_pro_sanitize_image',
		) 
	);
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'ultragym_pro_theme_options[service_bg_image]',
		array(
			'label'       		=> esc_html__( 'Background Image', 'ultra-gym-pro' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'ultra-gym-pro' ), 1350, 385 ),
			'section'     		=> 'ultragym_pro_service_section',
			'active_callback'	=> 'ultragym_pro_is_service_section_enable',
		) 
	) );

}

