<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'ultragym_pro_slider_section', array(
	'title'             => esc_html__( 'Slider','ultra-gym-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'ultra-gym-pro' ),
	'panel'             => 'ultragym_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[slider_section_enable]', 
	array(
		'default'			=> 	$options['slider_section_enable'],
		'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[slider_section_enable]',
	array(
		'label'             => esc_html__( 'Slider Section Enable', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_slider_section',
		'on_off_label' 		=> ultragym_pro_switch_options(),
	)
) );

// Slider autoplay enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[slider_autoplay_enable]',
	array(
		'default'			=> 	$options['slider_autoplay_enable'],
		'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[slider_autoplay_enable]',
	array(
		'label'             => esc_html__( 'Slider Autoplay Enable', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_slider_section',
		'active_callback'   => 'ultragym_pro_is_slider_section_enable',
		'on_off_label' 		=> ultragym_pro_switch_options(),
	)
) );


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[slider_autoplay_enable]',
		array(
			'selector'            => '#featured-slider .tooltiptext',
			'settings'            => 'ultragym_pro_theme_options[slider_autoplay_enable]',
		) 
	);
}

// Slider Social Menu enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[slider_social_menu_enable]',
	array(
		'default'			=> 	$options['slider_social_menu_enable'],
		'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[slider_social_menu_enable]',
	array(
		'label'             => esc_html__( 'Show Social Menu', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_slider_section',
		'active_callback'   => 'ultragym_pro_is_slider_section_enable',
		'on_off_label' 		=> ultragym_pro_switch_options(),
	)
) );

// Slider number control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[slider_count]',
	array(
		'default'          	=> $options['slider_count'],
		'sanitize_callback' => 'ultragym_pro_sanitize_number_range',
		'validate_callback' => 'ultragym_pro_validate_slider_count',
	)
);

$wp_customize->add_control( 'ultragym_pro_theme_options[slider_count]',
	array(
		'label'             => esc_html__( 'Number of Post', 'ultra-gym-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_slider_section',
		'active_callback'   => 'ultragym_pro_is_slider_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 5,
			'style' => 'width: 100px;'
			),
	)
);

// Slider content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[slider_content_type]',
	array(
		'default'          	=> $options['slider_content_type'],
		'sanitize_callback' => 'ultragym_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'ultragym_pro_theme_options[slider_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
		'section'           => 'ultragym_pro_slider_section',
		'type'				=> 'select',
		'active_callback' 	=> 'ultragym_pro_is_slider_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'ultra-gym-pro' ),
			'post' 		=> esc_html__( 'Post', 'ultra-gym-pro' ),
			'category' 	=> esc_html__( 'Category', 'ultra-gym-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[slider_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'ultragym_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[slider_content_page_'. $i .']', 
	array(
		'label'             => sprintf(esc_html__( 'Select Page: %d', 'ultra-gym-pro'), $i ),
		'section'           => 'ultragym_pro_slider_section',
		'choices'			=> ultragym_pro_page_choices(),
		'active_callback'	=> 'ultragym_pro_is_slider_section_content_page_enable',
	)
	) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[slider_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'ultragym_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[slider_content_post_'. $i .']',
		array(
			'label'             => sprintf(esc_html__( 'Select Post : %d', 'ultra-gym-pro'), $i ),
			'section'           => 'ultragym_pro_slider_section',
			'choices'			=> ultragym_pro_post_choices(),
			'active_callback'	=> 'ultragym_pro_is_slider_section_content_post_enable',
		)
	) );

	// UltraGym_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('ultragym_pro_theme_options[slider_separator'. $i .']',
		array(
			'sanitize_callback'      => 'ultragym_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new  UltraGym_Pro_Customize_Horizontal_Line($wp_customize,'ultragym_pro_theme_options[slider_separator'. $i .']',
	array(
			'active_callback'       => 'ultragym_pro_is_slider_section_separator_enable',
			'type'                  =>'hr',
			'section'               =>'ultragym_pro_slider_section',
		)
	));

endfor;

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[slider_category]',
	array(
		'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'ultragym_pro_theme_options[slider_category]', 
	array(
		'label'             => esc_html__( 'Select Categories', 'ultra-gym-pro' ),
		'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro' ),
		'type'           	=> 'dropdown-taxonomies',
		'section'           => 'ultragym_pro_slider_section',
		'active_callback'	=> 'ultragym_pro_is_slider_section_content_category_enable',
	)
 ) ); 


//slider_btn_txt
$wp_customize->add_setting('ultragym_pro_theme_options[slider_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['slider_btn_txt'],
    )
);

$wp_customize->add_control('ultragym_pro_theme_options[slider_btn_txt]',
    array(
        'section'			=> 'ultragym_pro_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'ultragym_pro_is_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[slider_btn_txt]',
		array(
			'selector'            => '#featured-slider article div.read-more a:nth-child(1)',
			'settings'            => 'ultragym_pro_theme_options[slider_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'ultragym_pro_slider_btn_txt_partial',
		) 
	);
}
