<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'ultragym_pro_team_section', array(
	'title'             => esc_html__( 'Team','ultra-gym-pro' ),
	'description'       => esc_html__( 'Team Section options.', 'ultra-gym-pro' ),
	'panel'             => 'ultragym_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            ultragym_pro_is_default_layout( $control )
            ||
            ultragym_pro_is_second_layout( $control )
            ||
            ultragym_pro_is_fourth_layout( $control )
            ||
            ultragym_pro_is_fifth_layout( $control )
        );
    },
) );

// Team content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_team_section',
	'on_off_label' 		=> ultragym_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[team_section_enable]', array(
		'selector'            => '#team .tooltiptext',
		'settings'            => 'ultragym_pro_theme_options[team_section_enable]',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'ultragym_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'ultra-gym-pro' ),
	'section'        	=> 'ultragym_pro_team_section',
	'active_callback' 	=> 'ultragym_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[team_title]', array(
		'selector'            => '#team h2.section-title',
		'settings'            => 'ultragym_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'ultragym_pro_team_title_partial',
    ) );
}

// team description setting and control
$wp_customize->add_setting( 'ultragym_pro_theme_options[team_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[team_sub_title]', array(
	'label'           	=> esc_html__( 'Section Sub Title', 'ultra-gym-pro' ),
	'section'        	=> 'ultragym_pro_team_section',
	'active_callback' 	=> 'ultragym_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[team_sub_title]', array(
		'selector'            => '#team p.section-subtitle',
		'settings'            => 'ultragym_pro_theme_options[team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'ultragym_pro_team_sub_title_partial',
    ) );
}


// Slider number control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'ultragym_pro_sanitize_number_range',
	'validate_callback' => 'ultragym_pro_validate_team_count',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Team', 'ultra-gym-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_team_section',
	'active_callback'   => 'ultragym_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// team content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[team_column]', array(
	'default'          	=> $options['team_column'],
	'sanitize_callback' => 'ultragym_pro_sanitize_select',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[team_column]', array(
	'label'             => esc_html__( 'Column Layout', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'ultragym_pro_is_team_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'ultra-gym-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'ultra-gym-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'ultra-gym-pro' ),
	),
) );

// Team content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'ultragym_pro_sanitize_select',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'ultragym_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'ultra-gym-pro' ),
		'post' 		=> esc_html__( 'Post', 'ultra-gym-pro' ),
		'category' 	=> esc_html__( 'Category', 'ultra-gym-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'ultra-gym-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'ultragym_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Taxonomies_Control( $wp_customize,'ultragym_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'ultra-gym-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'ultragym_pro_is_team_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :
	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'ultragym_pro_sanitize_page',
	) );

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'ultra-gym-pro' ), $i ),
		'section'           => 'ultragym_pro_team_section',
		'choices'			=> ultragym_pro_page_choices(),
		'active_callback'	=> 'ultragym_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'ultragym_pro_sanitize_page',
	) );

	$wp_customize->add_control( new  UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'ultra-gym-pro' ), $i ),
		'section'           => 'ultragym_pro_team_section',
		'choices'			=> ultragym_pro_post_choices(),
		'active_callback'	=> 'ultragym_pro_is_team_section_content_post_enable',
	) ) );

	// team title setting and control
	$wp_customize->add_setting( 'ultragym_pro_theme_options[team_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'ultragym_pro_theme_options[team_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'ultra-gym-pro' ), $i ),
		'section'        	=> 'ultragym_pro_team_section',
		'active_callback' 	=> 'ultragym_pro_is_team_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// team position setting and control
	$wp_customize->add_setting( 'ultragym_pro_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'ultragym_pro_theme_options[team_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'ultra-gym-pro' ), $i ),
		'section'        	=> 'ultragym_pro_team_section',
		'active_callback' 	=> 'ultragym_pro_is_team_section_enable',
		'type'				=> 'text',
	) );

	// team image setting and control.
	$wp_customize->add_setting( 'ultragym_pro_theme_options[team_image_' . $i . ']', array(
		'sanitize_callback' => 'ultragym_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'ultragym_pro_theme_options[team_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'ultra-gym-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'ultra-gym-pro' ), 382, 420 ),
			'section'     		=> 'ultragym_pro_team_section',
			'active_callback'	=> 'ultragym_pro_is_team_section_content_custom_enable',
	) ) );

	// team position setting and control
	$wp_customize->add_setting( 'ultragym_pro_theme_options[team_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'ultragym_pro_theme_options[team_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'ultra-gym-pro' ), $i ),
		'section'        	=> 'ultragym_pro_team_section',
		'active_callback' 	=> 'ultragym_pro_is_team_section_content_custom_enable',
		'type'				=> 'url',
	) );
	
if($options['home_layout'] == 'second-design' || $options['home_layout'] == 'default-design' || $options['home_layout'] == 'pro-design') {

	// team multiple input setting and control
	$wp_customize->add_setting( 'ultragym_pro_theme_options[team_social_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new  UltraGym_Pro_Multi_Input_Custom_Control( $wp_customize, 'ultragym_pro_theme_options[team_social_'. $i .']',
		array(
			'label'           => sprintf( esc_html__( 'Social Link %d', 'ultra-gym-pro' ), $i ),
			'button_text'	  => esc_html__( 'Add Social Link', 'ultra-gym-pro' ),
			'section'         => 'ultragym_pro_team_section',
			'active_callback' => 'ultragym_pro_is_team_section_enable',
			'type'			  => 'multi-input'
	) ) );
}

	// team hr setting and control
	$wp_customize->add_setting( 'ultragym_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'ultragym_pro_sanitize_html'
	) );

	$wp_customize->add_control( new  UltraGym_Pro_Customize_Horizontal_Line( $wp_customize, 'ultragym_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'ultragym_pro_team_section',
			'active_callback' => 'ultragym_pro_is_team_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

