<?php

/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section('ultragym_pro_testimonial_section', array(
    'title'         => esc_html__('Testimonials', 'ultra-gym-pro'),
    'description'   => esc_html__('Testimonials Section options.', 'ultra-gym-pro'),
    'panel'         => 'ultragym_pro_front_page_panel',
    'active_callback'   => function( $control ) {
        return ( 
            ultragym_pro_is_default_layout( $control )
            ||
            ultragym_pro_is_pro_layout( $control )
            ||
            ultragym_pro_is_second_layout( $control )
            ||
            ultragym_pro_is_third_layout( $control )
            ||
            ultragym_pro_is_fourth_layout( $control )
        );
    },
));

// Testimonial content enable control and setting
$wp_customize->add_setting('ultragym_pro_theme_options[testimonial_section_enable]', array(
    'default'           => $options['testimonial_section_enable'],
    'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
));

$wp_customize->add_control(new  UltraGym_Pro_Switch_Control($wp_customize, 'ultragym_pro_theme_options[testimonial_section_enable]', array(
    'label'         => esc_html__('Testimonial Section Enable', 'ultra-gym-pro'),
    'section'       => 'ultragym_pro_testimonial_section',
    'on_off_label'  => ultragym_pro_switch_options(),
)));

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[testimonial_section_enable]', array(
		'selector'            => '#testimonial .tooltiptext',
		'settings'            => 'ultragym_pro_theme_options[testimonial_section_enable]',
    ) );
}

// Testimonial section sub title control and setting
$wp_customize->add_setting('ultragym_pro_theme_options[testimonial_section_sub_title]', array(
    'sanitize_callback'     => 'sanitize_text_field',
    'transport'             => 'postMessage',
    'default'               => $options['testimonial_section_sub_title'],
));

$wp_customize->add_control('ultragym_pro_theme_options[testimonial_section_sub_title]', array(
    'label'             => esc_html__('Section Sub Title', 'ultra-gym-pro'),
    'section'           => 'ultragym_pro_testimonial_section',
    'type'              => 'text',
    'active_callback'   => 'ultragym_pro_is_testimonial_section_enable',
));
$wp_customize->selective_refresh->add_partial('ultragym_pro_theme_options[testimonial_section_sub_title]', array(
    'selector'          => '#testimonial .section-subtitle',
    'render_callback'   => 'ultragym_pro_testimonial_section_partial_sub_title',
    )
);

// Testimonial section title control and setting
$wp_customize->add_setting('ultragym_pro_theme_options[testimonial_section_title]', array(
    'default'               => $options['testimonial_section_title'],
    'sanitize_callback'     => 'sanitize_text_field',
    'transport'             => 'postMessage'
));

$wp_customize->add_control('ultragym_pro_theme_options[testimonial_section_title]', array(
    'label'                 => esc_html__('Section Title', 'ultra-gym-pro'),
    'section'               => 'ultragym_pro_testimonial_section',
    'type'                  => 'text',
    'active_callback'       => 'ultragym_pro_is_testimonial_section_enable',
));
$wp_customize->selective_refresh->add_partial('ultragym_pro_theme_options[testimonial_section_title]', array(
        'selector'          => '#testimonial .section-title',
        'render_callback'   => 'ultragym_pro_testimonial_section_partial_title',
    )
);

//Testimonial section content control type setting and control
$wp_customize->add_setting('ultragym_pro_theme_options[testimonial_content_type]', array(
    'default'               => $options['testimonial_content_type'],
    'sanitize_callback'     => 'ultragym_pro_sanitize_select',
));

$wp_customize->add_control('ultragym_pro_theme_options[testimonial_content_type]', array(
    'label'                 => esc_html__('Content Type', 'ultra-gym-pro'),
    'section'               => 'ultragym_pro_testimonial_section',
    'type'                  => 'select',
    'active_callback'       => 'ultragym_pro_is_testimonial_section_enable',
    'choices'               => array(
                                'page' => esc_html__('Page', 'ultra-gym-pro'),
                                'post' => esc_html__('Post', 'ultra-gym-pro'),
                                'category' => esc_html__('Category', 'ultra-gym-pro'),
                            ),
));


// Testimonial post number control and setting
$wp_customize->add_setting('ultragym_pro_theme_options[testimonial_posts_count]', array(
    'default'               => $options['testimonial_posts_count'],
    'sanitize_callback'     => 'absint',
));

$wp_customize->add_control('ultragym_pro_theme_options[testimonial_posts_count]', array(
    'label'                 => esc_html__('Number of Posts', 'ultra-gym-pro'),
    'description'           => esc_html__('Please input the number of of post to display and save. Then refresh the page to see the change.', 'ultra-gym-pro'),
    'section'               => 'ultragym_pro_testimonial_section',
    'active_callback'       => 'ultragym_pro_is_testimonial_section_enable',
    'type'                  => 'number',
));

for ($i = 1; $i <= $options['testimonial_posts_count']; $i++):
// Testimonial pages drop down chooser control and setting
    $wp_customize->add_setting('ultragym_pro_theme_options[testimonial_content_page_' . $i . ']', array(
        'sanitize_callback' => 'ultragym_pro_sanitize_page',
    ));

    $wp_customize->add_control(new  UltraGym_Pro_Dropdown_Chooser($wp_customize, 'ultragym_pro_theme_options[testimonial_content_page_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Page : %d', 'ultra-gym-pro'), $i),
        'section'           => 'ultragym_pro_testimonial_section',
        'choices'           => ultragym_pro_page_choices(),
        'active_callback'   => 'ultragym_pro_is_testimonial_section_content_page_enable',
    )));

    // Testimonial posts drop down chooser control and setting
    $wp_customize->add_setting('ultragym_pro_theme_options[testimonial_content_post_' . $i . ']', array(
        'sanitize_callback' => 'ultragym_pro_sanitize_page',
    ));

    $wp_customize->add_control(new  UltraGym_Pro_Dropdown_Chooser($wp_customize, 'ultragym_pro_theme_options[testimonial_content_post_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Post : %d', 'ultra-gym-pro'), $i),
        'section'           => 'ultragym_pro_testimonial_section',
        'choices'           => ultragym_pro_post_choices(),
        'active_callback'   => 'ultragym_pro_is_testimonial_section_content_post_enable',
    )));
    // Testimonial posts sub title control and setting
    $wp_customize->add_setting('ultragym_pro_theme_options[testimonial_post_designation_' . $i . ']', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));

    $wp_customize->add_control(new  UltraGym_Pro_Dropdown_Chooser($wp_customize, 'ultragym_pro_theme_options[testimonial_post_designation_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Designation : %d', 'ultra-gym-pro'), $i),
        'section'           => 'ultragym_pro_testimonial_section',
        'active_callback'   => 'ultragym_pro_is_testimonial_section_enable',
        'type'              => 'text',
    )));

    //testimonial separator
    $wp_customize->add_setting('ultragym_pro_theme_options[testimonial_separator'. $i .']',array(
        'sanitize_callback'      => 'ultragym_pro_sanitize_html',
    ));

    $wp_customize->add_control(new  UltraGym_Pro_Customize_Horizontal_Line($wp_customize,'ultragym_pro_theme_options[testimonial_separator'. $i .']',array(
        'active_callback'       => 'ultragym_pro_is_testimonial_section_enable',
        'type'                  =>'hr',
        'section'               =>'ultragym_pro_testimonial_section',
    )));

endfor;

// Testimonial category drop down chooser control and setting
$wp_customize->add_setting('ultragym_pro_theme_options[testimonial_category]', array(
    'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
));

$wp_customize->add_control(new  UltraGym_Pro_Dropdown_Taxonomies_Control($wp_customize, 'ultragym_pro_theme_options[testimonial_category]', array(
    'label'             => esc_html__('Select Categories', 'ultra-gym-pro'),
    'description'       => esc_html__('Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro'),
    'type'              => 'dropdown-taxonomies',
    'section'           => 'ultragym_pro_testimonial_section',
    'active_callback'   => 'ultragym_pro_is_testimonial_section_content_category_enable',
)));

if($options['home_layout'] != 'second-design'){

    $wp_customize->add_setting( 'ultragym_pro_theme_options[testimonial_bg_image]',
        array(
            'sanitize_callback' => 'ultragym_pro_sanitize_image',
        ) 
    );
    
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'ultragym_pro_theme_options[testimonial_bg_image]',
        array(
            'label'       		=> esc_html__( 'Background Image', 'ultra-gym-pro' ),
            'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'ultra-gym-pro' ), 1350, 385 ),
            'section'     		=> 'ultragym_pro_testimonial_section',
            'active_callback'	=> 'ultragym_pro_is_testimonial_section_enable',
        )
    ) );
}
