<?php
/**
 * Video Section options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add Video section
$wp_customize->add_section( 'ultragym_pro_video_section', 
    array(
        'title'             => esc_html__( 'Video','ultra-gym-pro' ),
        'description'       => esc_html__( 'Video Section options.', 'ultra-gym-pro' ),
        'panel'             => 'ultragym_pro_front_page_panel',
        'active_callback'   => function( $control ) {
            return ( 
                ultragym_pro_is_default_layout( $control )
                ||
                ultragym_pro_is_pro_layout( $control )
                ||
                ultragym_pro_is_second_layout( $control )
                ||
                ultragym_pro_is_third_layout( $control )
                ||
                ultragym_pro_is_fourth_layout( $control )
                ||
                ultragym_pro_is_fifth_layout( $control )
            );
        },
    ) 
);

// Video content enable control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[video_section_enable]', 
    array(
        'default'			=> 	$options['video_section_enable'],
        'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
    ) 
);

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[video_section_enable]',
    array(
        'label'             => esc_html__( 'Video Section Enable', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_video_section',
        'on_off_label' 		=> ultragym_pro_switch_options(),
    ) 
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[video_section_enable]',
        array(
            'selector'            => '#video .tooltiptext',
            'settings'            => 'ultragym_pro_theme_options[video_section_enable]',
        ) 
    );
}

// video section title control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[video_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['video_section_title'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('ultragym_pro_theme_options[video_section_title]',
    array(
        'label'             => esc_html__( 'Section Sub Title', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_video_section',
        'type'              =>'text',
        'active_callback'	=> 'ultragym_pro_is_video_section_enable',
    )
);
$wp_customize->selective_refresh->add_partial(
    'ultragym_pro_theme_options[video_section_title]',
    array(
        'selector'            => '#video .section-subtitle',
        'render_callback'     => 'ultragym_pro_video_section_partial_title',
    )
);

// Video content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[video_content_type]',
    array(
        'default'          	=> $options['video_content_type'],
        'sanitize_callback' => 'ultragym_pro_sanitize_select',
    ) 
);

$wp_customize->add_control( 'ultragym_pro_theme_options[video_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'ultra-gym-pro' ),
        'section'           => 'ultragym_pro_video_section',
        'type'				=> 'select',
        'active_callback' 	=> 'ultragym_pro_is_video_section_enable',
        'choices'			=> array( 
                'page' 		=> esc_html__( 'Page', 'ultra-gym-pro' ),
                'post' 		=> esc_html__( 'Post', 'ultra-gym-pro' ),
                'category' 	=> esc_html__( 'Category', 'ultra-gym-pro' ),
                'custom' 	=> esc_html__( 'Custom', 'ultra-gym-pro' ),
        ),
    ) 
);

	// video pages drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[video_content_page]', 
        array(
            'sanitize_callback' => 'ultragym_pro_sanitize_page',
        ) 
    );

	$wp_customize->add_control( new UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[video_content_page]',
        array(
            'label'             => esc_html__( 'Select Page', 'ultra-gym-pro' ),
            'section'           => 'ultragym_pro_video_section',
            'choices'			=> ultragym_pro_page_choices(),
            'active_callback'	=> 'ultragym_pro_is_video_section_content_page_enable',
        ) 
    ) );

	// video posts drop down chooser control and setting
	$wp_customize->add_setting( 'ultragym_pro_theme_options[video_content_post]',
        array(
            'sanitize_callback' => 'ultragym_pro_sanitize_page',
        )
    );

	$wp_customize->add_control( new UltraGym_Pro_Dropdown_Chooser( $wp_customize, 'ultragym_pro_theme_options[video_content_post]',
        array(
            'label'             => esc_html__( 'Select Post', 'ultra-gym-pro' ),
            'section'           => 'ultragym_pro_video_section',
            'choices'			=> ultragym_pro_post_choices(),
            'active_callback'	=> 'ultragym_pro_is_video_section_content_post_enable',
        )
    ) );


// video posts drop down chooser control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[video_category]', 
    array(
        'sanitize_callback' => 'ultragym_pro_sanitize_single_category',
    )
);

$wp_customize->add_control( new UltraGym_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'ultragym_pro_theme_options[video_category]',
    array(
        'label'             => esc_html__( 'Select Categories', 'ultra-gym-pro' ),
        'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'ultra-gym-pro' ),
        'type'           	=> 'dropdown-taxonomies',
        'section'           => 'ultragym_pro_video_section',
        'active_callback'	=> 'ultragym_pro_is_video_section_content_category_enable',
    )
) ); 

// Video title setting
$wp_customize->add_setting('ultragym_pro_theme_options[video_custom_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['video_custom_title']
    )
);

$wp_customize->add_control('ultragym_pro_theme_options[video_custom_title]',
    array(
        'section'			=> 'ultragym_pro_video_section',
        'label'				=> esc_html__( 'Title:', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'ultragym_pro_if_video_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('ultragym_pro_theme_options[video_custom_title]',
    array(
        'selector'            => '#video .section-title',
        'render_callback'     => 'ultragym_pro_video_section_partial_custom_title',
    )
);

// Video content setting
$wp_customize->add_setting('ultragym_pro_theme_options[video_custom_content]',
    array(
        'sanitize_callback' => 'sanitize_textarea_field',
        'transport'			=> 'postMessage',
        'default'           => $options['video_custom_content']

    )
);

$wp_customize->add_control('ultragym_pro_theme_options[video_custom_content]',
    array(
        'section'			=> 'ultragym_pro_video_section',
        'label'				=> esc_html__( 'Content:', 'ultra-gym-pro' ),
        'type'          	=>'textarea',
        'active_callback'	=> 'ultragym_pro_if_video_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('ultragym_pro_theme_options[video_custom_content]',array(
        'selector'            => '#video .section-header span.content',
        'render_callback'     => 'ultragym_pro_video_section_partial_custom_content',
    )
);

// Video image setting
$wp_customize->add_setting(
    'ultragym_pro_theme_options[video_custom_image]',
    array(
        'sanitize_callback' => 'ultragym_pro_sanitize_image',
    )
);

$wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize, 'ultragym_pro_theme_options[video_custom_image]',
        array(
            'section'			=> 'ultragym_pro_video_section',
            'label'				=> esc_html__( 'Image:', 'ultra-gym-pro' ),
            'active_callback' 	=> 'ultragym_pro_if_video_section_content_custom_enable',
        )
    )
);

// Video content setting
$wp_customize->add_setting('ultragym_pro_theme_options[video_btn_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['video_btn_label']

    )
);

$wp_customize->add_control('ultragym_pro_theme_options[video_btn_label]',
    array(
        'section'			=> 'ultragym_pro_video_section',
        'label'				=> esc_html__( 'Button Label:', 'ultra-gym-pro' ),
        'type'          	=>'text',
        'active_callback'	=> 'ultragym_pro_is_video_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultragym_pro_theme_options[video_btn_label]',
        array(
            'selector'            => '#video div.read-more a',
            'settings'            => 'ultragym_pro_theme_options[video_btn_label]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'ultragym_pro_video_btn_label_partial',
        ) 
    );
}

if($options['home_layout'] == 'second-design'){
    
    
    $wp_customize->add_setting( 'ultragym_pro_theme_options[video_btn_label_url]',
        array(
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    
    $wp_customize->add_control( 'ultragym_pro_theme_options[video_btn_label_url]',
        array(
            'label'           	=> esc_html__( 'Button Url', 'ultra-gym-pro' ),
            'section'        	=> 'ultragym_pro_video_section',
            'active_callback' 	=> 'ultragym_pro_if_video_section_content_custom_enable',
            'type'				=> 'url',
        ) 
    );
}

$wp_customize->add_setting( 'ultragym_pro_theme_options[video_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'ultragym_pro_theme_options[video_url]',
    array(
        'label'           	=> esc_html__( 'Video Url', 'ultra-gym-pro' ),
        'section'        	=> 'ultragym_pro_video_section',
        'active_callback' 	=> 'ultragym_pro_is_video_section_enable',
        'type'				=> 'url',
    ) 
);
