<?php
/**
 * Archive options
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'ultragym_pro_archive_section', array(
	'title'             => esc_html__( 'Blog/Archive','ultra-gym-pro' ),
	'description'       => esc_html__( 'Archive section options.', 'ultra-gym-pro' ),
	'panel'             => 'ultragym_pro_theme_options_panel',
) );

// Your latest posts title setting and control.
$wp_customize->add_setting( 'ultragym_pro_theme_options[your_latest_posts_title]', array(
	'default'           => $options['your_latest_posts_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[your_latest_posts_title]', array(
	'label'             => esc_html__( 'Your Latest Posts Title', 'ultra-gym-pro' ),
	'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_archive_section',
	'type'				=> 'text',
	'active_callback'   => 'ultragym_pro_is_latest_posts'
) );

// Archive date meta setting and control.
$wp_customize->add_setting( 'ultragym_pro_theme_options[hide_date]', array(
	'default'           => $options['hide_date'],
	'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[hide_date]', array(
	'label'             => esc_html__( 'Hide Date', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_archive_section',
	'on_off_label' 		=> ultragym_pro_hide_options(),
) ) );

// Archive date meta setting and control.
$wp_customize->add_setting( 'ultragym_pro_theme_options[hide_author]', array(
	'default'           => $options['hide_author'],
	'sanitize_callback' => 'ultragym_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new  UltraGym_Pro_Switch_Control( $wp_customize, 'ultragym_pro_theme_options[hide_author]', array(
	'label'             => esc_html__( 'Hide Author', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_archive_section',
	'on_off_label' 		=> ultragym_pro_hide_options(),
) ) );

// features content type control and setting
$wp_customize->add_setting( 'ultragym_pro_theme_options[blog_column]', array(
	'default'          	=> $options['blog_column'],
	'sanitize_callback' => 'ultragym_pro_sanitize_select',
	//'transport'			=> 'refresh',
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[blog_column]', array(
	'label'             => esc_html__( 'Column Layout', 'ultra-gym-pro' ),
	'section'           => 'ultragym_pro_archive_section',
	'type'				=> 'select',
	'choices'			=> array( 
		'col-1'		=> esc_html__( 'One Column', 'ultra-gym-pro' ),
		'col-2'		=> esc_html__( 'Two Column', 'ultra-gym-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'ultra-gym-pro' ),
	),
) );

// read more text setting and control
$wp_customize->add_setting( 'ultragym_pro_theme_options[read_more_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['read_more_text'],
) );

$wp_customize->add_control( 'ultragym_pro_theme_options[read_more_text]', array(
	'label'           	=> esc_html__( 'Read More Text Label', 'ultra-gym-pro' ),
	'section'        	=> 'ultragym_pro_archive_section',
	'type'				=> 'text',
) );

