<?php
/**
 * Banner section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_about_section() {
    	$options = ultragym_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'ultragym_pro_section_status', true, 'about_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'pro-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design' ) ) ) {
            $about_enable = false;
        }

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_about_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render about section now.
        ultragym_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultragym_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input about section details.
    */
    function ultragym_pro_get_about_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
            case 'page':
                $page_id = '';
                if ( ! empty( $options['about_content_page'] ) )
                    $page_id = isset($options['about_content_page']) ? $options['about_content_page'] : '' ;
                $args = array(
                    'post_type'             => 'page',
                    'p'                     =>  absint( $page_id ),
                    'ignore_sticky_posts'   => true,
                    );
                break;

            case 'post':
                $post_id = '';
                if ( ! empty( $options['about_content_post'] ) )
                    $post_id = isset($options['about_content_post'])?$options['about_content_post']:'';
                $args = array(
                    'post_type'             => 'post',
                    'p'                     => absint( $post_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
                break;

            case 'category':
                $cat_id = isset( $options['about_category'] ) ? $options['about_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'cat'                   => absint( $cat_id ),
                    'posts_per_page'        => 1,
                    'ignore_sticky_posts'   => true,
                    );                    
                break;

            case 'custom':
                $page_post['content']   = !empty($options['about_custom_content']) ? $options['about_custom_content'] : esc_html__('When I first started training for marathons a little over ten years ago, my coach told me something I’ve never forgotten: that I would need to learn how to be comfortable with being uncomfortable.','ultra-gym-pro');
                $page_post['title']     = !empty($options['about_custom_title'])? $options['about_custom_title']: esc_html__('Free Membership for Three Months','ultra-gym-pro');
                $page_post['subtitle']  = !empty($options['about_section_title'])? $options['about_section_title']: esc_html__('Featured Content','ultra-gym-pro');
                $page_post['image']     = !empty($options['about_custom_image'])? $options['about_custom_image']: get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['url']       = !empty($options['about_btn_url'])? $options['about_btn_url']: '';
                array_push( $content, $page_post );
                return $content;
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['content']   = has_excerpt() ? get_the_excerpt() : ultragym_pro_trim_content(30);
                $page_post['subtitle']  = !empty($options['about_section_title'])? $options['about_section_title']: esc_html__('Featured Content','ultra-gym-pro');
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['url']       = get_the_permalink( );
                $page_post['title']     = get_the_title();
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'ultragym_pro_filter_about_section_details', 'ultragym_pro_get_about_section_details' );


if ( ! function_exists( 'ultragym_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_about_section( $content_details = array() ) {
        $options        = ultragym_pro_get_theme_options();
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php $content = $content_details[0]; ?>
        <div id="ultragym_pro_about_section">
            <div id="about-us" class="<?php if($options['home_layout'] != 'default-design' && $options['home_layout'] != 'second-design' && $options['home_layout'] != 'pro-design') echo 'page-section'; ?>">
            
                <div class="wrapper">
                    <article class="has-post-thumbnail">
                        
                        <?php if($options['home_layout'] == 'default-design' || $options['home_layout'] == 'pro-design' || $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'fifth-design') :?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                <a href="<?php echo esc_url($content['url']); ?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']); ?>"></a>
                            </div><!-- .featured-image -->
                            <?php endif; ?>
                            
                            <div class="entry-container">
                            <?php if(is_customize_preview()) ultragym_pro_section_tooltip('about-us'); ?>

                            <div class="section-header">
                                <p class="section-subtitle"><?php echo esc_html($content['subtitle']); ?></p>
                                <h2 class="section-title"><?php echo esc_html($content['title']); ?></h2>
                            </div><!-- .section-header -->

                            <div class="entry-content">
                                <p><?php echo wp_kses_post($content['content']); ?></p>
                            </div><!-- .entry-content -->

                            <?php if(!empty($options['about_btn_label']) && !empty($content['url']) ): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['about_btn_label'])?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>

                        </div><!-- .entry-container -->

                        <?php if($options['home_layout'] == 'second-design') :?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                <a href="<?php echo esc_url($content['url']); ?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']); ?>"></a>
                            </div><!-- .featured-image -->
                        <?php endif; ?>
                        
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #about-us -->
        </div>
        
    <?php
    }    
endif; ?>
