<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_blog_section() {
        $options = ultragym_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'ultragym_pro_section_status', true, 'blog_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'pro-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design', 'sixth-design', 'seventh-design' ) ) ) {
            $blog_enable = false;
        }

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render blog section now.
        ultragym_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultragym_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input blog section details.
    */
    function ultragym_pro_get_blog_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 3;
        
        
        $content = array();
        switch ( $blog_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $blog_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $blog_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $blog_count ),
                    'category__not_in'      => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['author_id'] = get_the_author_meta('ID');
                $page_post['excerpt']   = ultragym_pro_trim_content( 30);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'ultragym_pro_filter_blog_section_details', 'ultragym_pro_get_blog_section_details' );


if ( ! function_exists( 'ultragym_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_blog_section( $content_details = array() ) {
        $options                = ultragym_pro_get_theme_options();
        $blog_load_more_btn_url = (!empty($options['blog_load_more_btn_url'])) ? $options['blog_load_more_btn_url'] : ''; 
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultragym_pro_blog_section">
             <div id="blog" class="page-section <?php echo ($options['home_layout'] != 'third-design') ? 'no-padding-top' : ''; ?>">
                
                <div class="wrapper">
                    <?php if(is_customize_preview()) ultragym_pro_section_tooltip('blog'); ?>
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html($options['blog_sub_title'])?></p>
                        <h2 class="section-title"><?php echo esc_html($options['blog_title'])?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content">

                        <div class="<?php echo ( in_array($options['home_layout'], array('default-design', 'pro-design', 'second-design')) ) ? 'archive-blog-wrapper' : 'blog-wrapper col-3'; ?>">
                            <?php foreach ($content_details as $content):?>
                            <article class="has-post-thumbnail">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']);?>');">
                                    <a href="<?php echo esc_url($content['url']);?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']); ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">

                                    <span class="cat-links">
                                        <ul class="post-categories">
                                            <?php the_category(',', '', $content['id']); ?>
                                        </ul>
                                    </span>

                                    <header class="entry-header">
                                       <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" tabindex="0"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                       <p><?php echo wp_kses_post($content['excerpt']);?></p>
                                    </div><!-- .entry-content -->

                                    <?php if( in_array($options['home_layout'], array('default-design', 'pro-design', 'second-design'))) : ?>
                                    <div class="more-link">
                                        <a href="<?php echo esc_url($content['url']); ?>" tabindex="0"><?php echo esc_html($options['blog_post_read_more_btn_label']); ?></a>
                                    </div>
                                    <?php endif; ?>

                                    <div class="entry-meta">
                                        <?php 
                                        ultragym_pro_posted_on($content['id']);
                                        echo ultragym_pro_author($content['author_id']); ?>
                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            </article>
                            <?php endforeach; ?>

                            <?php if(( in_array($options['home_layout'], array('default-design', 'pro-design', 'second-design'))) && !empty($blog_load_more_btn_url) && !empty($options['blog_load_more_btn_label'])) : ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url($options['blog_load_more_btn_url']); ?>" class="btn"><?php echo esc_html($options['blog_load_more_btn_label']); ?></a>
                                </div>
                            <?php endif; ?>
                            
                        </div><!-- .archive -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- .blog -->
        </div>
           
    <?php }
endif;  ?>
