<?php
/**
 * Banner section
 *
 * This is the template for the content of contact section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_contact_section' ) ) :
    /**
    * Add contact section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_contact_section() {
    	$options = ultragym_pro_get_theme_options();
        // Check if contact is enabled on frontpage
        $contact_enable = apply_filters( 'ultragym_pro_section_status', true, 'contact_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'pro-design', 'second-design' ) ) ) {
             $contact_enable = false;
        }

        if ( true !== $contact_enable ) {
            return false;
        }
        // Get contact section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_contact_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render contact section now.
        ultragym_pro_render_contact_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultragym_pro_get_contact_section_details' ) ) :
    /**
    * contact section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input contact section details.
    */
    function ultragym_pro_get_contact_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        $content = array();
        $content['contact_map_shortcode']       = (!empty($options['contact_map_shortcode'])) ? $options['contact_map_shortcode'] : '';
        $content['contact_section_shortcode']   = (!empty($options['contact_section_shortcode'])) ? $options['contact_section_shortcode'] : '';
        $content['contact_section_title']       = (!empty($options['contact_section_title'])) ? $options['contact_section_title'] : esc_html__('Stay In Touch!!', 'ultra-gym-pro');
        $content['contact_section_subtitle']    = (!empty($options['contact_section_subtitle'])) ? $options['contact_section_subtitle'] : esc_html__('CONTACT US', 'ultra-gym-pro');

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// contact section content details.
add_filter( 'ultragym_pro_filter_contact_section_details', 'ultragym_pro_get_contact_section_details' );


if ( ! function_exists( 'ultragym_pro_render_contact_section' ) ) :
  /**
   * Start contact section
   *
   * @return string contact content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_contact_section( $content_details = array() ) {
        $options        = ultragym_pro_get_theme_options();
        
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultragym_pro_contact_section">
        <?php if($options['home_layout'] == 'second-design'): ?>
           
                <div id="contact" class="page-section no-padding-top">                
                    <div class="wrapper">
                        <?php if(is_customize_preview()) ultragym_pro_section_tooltip('blog'); ?>
                        <div class="section-content clear col-2">
                            <article class="hentry">
                            <div class="section-header">
                            <p class="section-subtitle"><?php echo esc_html( $content_details['contact_section_subtitle'] ); ?></p>
                            <h2 class="section-title"><?php echo esc_html( $content_details['contact_section_title'] ); ?></h2>
                        </div><!-- .section-header -->

                                <div class="section-content">
                                    <div class="widget widget_contact_info">
                                        <ul>
                                            <?php if(!empty($options['contact_section_phoneNumber'])): ?>
                                                <li>
                                                    <div class="icon">
                                                        <?php echo ultragym_pro_get_svg( array( 'icon' => 'phone') ); ?>
                                                    </div>

                                                    <div class="details phone-number">
                                                        <label><?php esc_html_e('Phone:', 'ultra-gym-pro'); ?></label>
                                                        <span><a href="tel:<?php echo esc_attr($options['contact_section_phoneNumber']); ?>"><?php echo esc_html($options['contact_section_phoneNumber']); ?></a></span>
                                                    </div><!-- .details -->
                                                </li>
                                            <?php endif; ?>

                                            <?php if(!empty($options['contact_section_address'])): ?>
                                                <li>
                                                    <div class="icon">
                                                        <?php echo ultragym_pro_get_svg( array( 'icon' => 'map') ); ?>
                                                    </div>
                                                    <div class="details address">
                                                        <label><?php esc_html_e('Address:', 'ultra-gym-pro'); ?></label>
                                                        <span><?php echo esc_html($options['contact_section_address']); ?></span>
                                                    </div><!-- .details -->
                                                </li>
                                            <?php endif; ?>

                                            <?php if(!empty($options['contact_section_email'])): ?>
                                                <li>
                                                    <div class="icon">
                                                        <?php echo ultragym_pro_get_svg( array( 'icon' => 'message') ); ?>
                                                    </div>
                                                    <div class="details mail">
                                                        <label><?php esc_html_e('Mail:', 'ultra-gym-pro'); ?></label>
                                                        <span><a href="mailto:<?php echo esc_attr($options['contact_section_email']); ?>"><?php echo esc_html($options['contact_section_email']); ?></a></span>
                                                    </div><!-- .details -->
                                                </li>
                                            <?php endif; ?>
                                        </ul>
                                    </div><!-- .widget -->
                                </div>
                            </article><!-- .hentry -->

                           <article class="hentry">
                            <?php echo do_shortcode( wp_kses_post( $content_details['contact_section_shortcode'] ) );  ?>
                           </article>
                        </div><!-- .section-content -->

                    </div><!-- .wrapper -->
                </div><!-- #contact -->

            <?php else: ?>

                <div id="contact" class="page-section">
                    
                    <div class="wrapper">
                        <?php if(is_customize_preview()) ultragym_pro_section_tooltip('contact'); ?>
                        <div class="section-header">
                            <p class="section-subtitle"><?php echo esc_html( $content_details['contact_section_subtitle'] ); ?></p>
                            <h2 class="section-title"><?php echo esc_html( $content_details['contact_section_title'] ); ?></h2>
                        </div><!-- .section-header -->

                        <div class="section-content clear col-2">
                            <article class="hentry">
                                <?php echo do_shortcode( wp_kses_post( $content_details['contact_map_shortcode'] ) );  ?>
                            </article><!-- .hentry -->

                            <article class="hentry">
                               <div class="contact-address">
                                    <div class="widget widget_contact_info">
                                        <ul>
                                            <?php if(!empty($options['contact_section_phoneNumber'])): ?>
                                                <li>
                                                    <div class="icon">
                                                        <?php echo ultragym_pro_get_svg( array( 'icon' => 'phone') ); ?>
                                                    </div>

                                                    <div class="details phone-number">
                                                        <span><a href="tel:<?php echo esc_attr($options['contact_section_phoneNumber']); ?>"><?php echo esc_html($options['contact_section_phoneNumber']); ?></a></span>
                                                    </div><!-- .details -->
                                                </li>
                                            <?php endif; ?>

                                            <?php if(!empty($options['contact_section_address'])): ?>
                                                <li>
                                                    <div class="icon">
                                                        <?php echo ultragym_pro_get_svg( array( 'icon' => 'map') ); ?>
                                                    </div>
                                                    <div class="details address">
                                                        <span><?php echo esc_html($options['contact_section_address']); ?></span>
                                                    </div><!-- .details -->
                                                </li>
                                            <?php endif; ?>

                                            <?php if(!empty($options['contact_section_email'])): ?>
                                                <li>
                                                    <div class="icon">
                                                        <?php echo ultragym_pro_get_svg( array( 'icon' => 'message') ); ?>
                                                    </div>
                                                    <div class="details mail">
                                                        <span><a href="mailto:<?php echo esc_attr($options['contact_section_email']); ?>"><?php echo esc_html($options['contact_section_email']); ?></a></span>
                                                    </div><!-- .details -->
                                                </li>
                                            <?php endif; ?>

                                        </ul>
                                    </div><!-- .widget -->
                                </div><!-- .contact-address -->
                            <?php echo do_shortcode( wp_kses_post( $content_details['contact_section_shortcode'] ) );  ?>
                            </article>
                        </div><!-- .section-content -->

                    </div><!-- .wrapper -->
                </div><!-- #contact -->
            
           
        <?php endif ; ?>
        </div>
<?php    }    
endif; ?>
