<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_counter_section() {
        $options = ultragym_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'ultragym_pro_section_status', true, 'counter_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'third-design', 'fourth-design' ) ) ) {
            $counter_enable = false;
        }

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        ultragym_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'ultragym_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_counter_section() {
        $options = ultragym_pro_get_theme_options();
        $image   = empty( $options['counter_image'] ) ? '' : $options['counter_image'] ;
        $counter_count = ! empty( $options['counter_count'] ) ? $options['counter_count'] : 4;
        $contents = array();
        for( $i= 1; $i <= absint( $counter_count ); $i++ ){
            $page_post['icon']      = empty( $options['counter_content_icon_'.$i] ) ? '' : $options['counter_content_icon_'.$i] ;
            $page_post['title']     = empty( $options['counter_title_'.$i] ) ? '' :$options['counter_title_'.$i];
            $page_post['number']    = empty( $options['counter_number_'.$i] ) ? '' :$options['counter_number_'.$i];
            array_push( $contents, $page_post );
        }
        if(empty($contents)) return; 
        ?>
        <div id="ultragym_pro_counter_section">
            <div id="counter" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ) ; ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php if(is_customize_preview()) ultragym_pro_section_tooltip('counter'); ?>

                    <div class="section-content clear col-4">
                    <?php foreach ( $contents as $content ): ?>

                        <article>
                            <header class="entry-header">
                                <div class="counter-icon">
                                    <i class="fa <?php echo esc_attr( $content['icon'] ) ; ?>"></i>
                                </div><!-- .counter-icon -->

                                <h2 class="counter-value"><?php echo esc_html( $content['number'] ); ?>  </h2>
                                <h3 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h3>
                            </header>
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .business-section-content -->
                </div><!-- .wrapper -->
            </div>
        </div>
        
    <?php }
endif;
