<?php
/**
 * Events section
 *
 * This is the template for the content of event section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_event_section' ) ) :
    /**
    * Add event section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_event_section() {
    	$options = ultragym_pro_get_theme_options();
        // Check if event is enabled on frontpage
        $event_enable = apply_filters( 'ultragym_pro_section_status', true, 'event_section_enable' );

        if ( !in_array( $options['home_layout'], array('default-design', 'second-design' ) ) ) {
            $event_enable = false;
        }
 
        if ( true !== $event_enable ) {
            return false;
        }
        // Get event section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_event_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render event section now.
        ultragym_pro_render_event_section( $section_details );
    }
endif; 

if ( ! function_exists( 'ultragym_pro_get_event_section_details' ) ) :
    /**
    * event section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input event section details.
    */
    function ultragym_pro_get_event_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        $event_content_type  = $options['event_content_type'];
        $event_count = ! empty( $options['event_count'] ) ? $options['event_count'] : 3;
        
        $content = array();
        switch ( $event_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_page_' . $i] ) )
                        $page_ids[] = $options['event_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_post_' . $i] ) )
                        $post_ids[] = $options['event_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $event_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['event_category'] ) ? $options['event_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $event_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['content']   = ultragym_pro_trim_content(10);
                $page_post['url']       = get_the_permalink();

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// event section content details.
add_filter( 'ultragym_pro_filter_event_section_details', 'ultragym_pro_get_event_section_details' );


if ( ! function_exists( 'ultragym_pro_render_event_section' ) ) :
  /**
   * Start event section
   *
   * @return string event content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_event_section( $content_details = array() ) {
        $options    = ultragym_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultragym_pro_event_section">
            <div id="event">
                <div class="col-3 clear">

                <?php foreach ( $content_details as $i=>$content ) : ?>

                    <article>
                <?php if(is_customize_preview() && $i==1) ultragym_pro_section_tooltip('event'); ?>

                        <div class="event-wrapper">
                            <div class="event-icon">
                                <a href="<?php echo esc_url($content['url']); ?>">
                                    <i class="fa <?php echo esc_attr( !empty( $options['event_icon_' . ($i+1)] ) ? $options['event_icon_' . ($i+1)] : 'fa-podcast' ); ?>"></i>
                                </a>
                            </div><!-- .event-icon -->
                            
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post($content['content']); ?></p>
                            </div><!-- .entry-content -->

                            <?php if(!empty($options['event_btn_txt_'.(absint($i)+1).''])): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['event_btn_txt_'.(absint($i)+1).'']); ?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                        </div><!-- .event-wrapper -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .col-3 -->
            </div><!-- #expert -->
        </div>
            
    <?php
    }    
endif; ?>
