<?php
/**
 * Banner section
 *
 * This is the template for the content of expert section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_expert_section' ) ) :
    /**
    * Add expert section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_expert_section() {
    	$options = ultragym_pro_get_theme_options();
        // Check if expert is enabled on frontpage
        $expert_enable = apply_filters( 'ultragym_pro_section_status', true, 'expert_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'pro-design' ) ) ) {
             $expert_enable = false;
        }

        if ( true !== $expert_enable ) {
            return false;
        }
        // Get expert section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_expert_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render expert section now.
        ultragym_pro_render_expert_section( $section_details );
}

endif;

if ( ! function_exists( 'ultragym_pro_get_expert_section_details' ) ) :
    /**
    * expert section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input expert section details.
    */
    function ultragym_pro_get_expert_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        $expert_content_type    = $options['expert_content_type'];
        $expert_count           = ! empty( $options['expert_count'] ) ? $options['expert_count'] : 4;
        
        $content = array();
        switch ( $expert_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $expert_count; $i++ ) {
                    if ( ! empty( $options['expert_content_page_' . $i] ) )
                        $page_ids[] = $options['expert_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $expert_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $expert_count; $i++ ) {
                    if ( ! empty( $options['expert_content_post_' . $i] ) )
                        $post_ids[] = $options['expert_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $expert_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['expert_category'] ) ? $options['expert_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $expert_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = ultragym_pro_trim_content(15);
                $page_post['author']    = ultragym_pro_author();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// expert section content details.
add_filter( 'ultragym_pro_filter_expert_section_details', 'ultragym_pro_get_expert_section_details' );


if ( ! function_exists( 'ultragym_pro_render_expert_section' ) ) :
  /**
   * Start expert section
   *
   * @return string expert content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_expert_section( $content_details = array() ) {
        $options = ultragym_pro_get_theme_options();
        $expert_column = (!empty($options['expert_column'])) ? $options['expert_column'] : 'col-3';
        
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultragym_pro_expert_section">
            <div id="expert">
                <div class="<?php echo esc_attr($expert_column); ?> clear">
                    <?php foreach ( $content_details as $i => $content ) : ?>
                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo $content['image']; ?>');"></div><!-- .featured-image -->
                        
                        <div class="entry-container">
                            <?php if(is_customize_preview() && $i==1) ultragym_pro_section_tooltip('expert'); ?>
                            <header class="entry-header">
                                <?php if(!empty($options['expert_subtitle_'.($i+1)])) echo '<span>'. esc_html($options['expert_subtitle_'.($i+1)]). '</span>'; ?>
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                            
                            <?php if(!empty($options['expert_btn_txt'])): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['expert_btn_txt']); ?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .col-3 -->
            </div><!-- #expert -->
        </div>
       

    <?php
    }    
endif;

