<?php
/**
 * Blog section
 *
 * This is the template for the content of popular_post section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_popular_post_section' ) ) :
    /**
    * Add popular_post section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_popular_post_section() {
        $options = ultragym_pro_get_theme_options();
        // Check if popular_post is enabled on frontpage
        $popular_post_enable = apply_filters( 'ultragym_pro_section_status', true, 'popular_post_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'sixth-design') ) ) {
            $popular_post_enable = false;
        }

        if ( true !== $popular_post_enable ) {
            return false;
        }
        // Get popular_post section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_popular_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render popular_post section now.
        ultragym_pro_render_popular_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultragym_pro_get_popular_post_section_details' ) ) :
    /**
    * popular_post section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input popular_post section details.
    */
    function ultragym_pro_get_popular_post_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        $popular_post_content_type  = $options['popular_post_content_type'];
        $popular_post_count = ! empty( $options['popular_post_count'] ) ? $options['popular_post_count'] : 2;
        
        
        $content = array();
        switch ( $popular_post_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_post_count; $i++ ) {
                    if ( ! empty( $options['popular_post_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_post_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_post_count; $i++ ) {
                    if ( ! empty( $options['popular_post_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_post_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $popular_post_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_post_content_category'] ) ? $options['popular_post_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $popular_post_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['popular_post_category_exclude'] ) ? $options['popular_post_category_exclude'] : array();
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $popular_post_count ),
                    'category__not_in'      => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = ultragym_pro_trim_content( 30);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_post section content details.
add_filter( 'ultragym_pro_filter_popular_post_section_details', 'ultragym_pro_get_popular_post_section_details' );


if ( ! function_exists( 'ultragym_pro_render_popular_post_section' ) ) :
  /**
   * Start popular_post section
   *
   * @return string popular_post content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_popular_post_section( $content_details = array() ) {
        $options                = ultragym_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="ultragym_pro_popular_post_section">
            <div id="blog-latest-posts" class="relative page-section no-padding-top">
                <div class="wrapper">
                    
                    <?php if(is_customize_preview()) ultragym_pro_section_tooltip('blog-latest-posts'); ?>
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html($options['popular_post_sub_title'])?></p>
                        <h2 class="section-title"><?php echo esc_html($options['popular_post_title'])?></h2>
                    </div><!-- .section-header -->

                    <div class="blog-latest-posts col-2">
                        <?php foreach($content_details as $content) : ?>

                            <article>
                                <div class="blog-post-wrapper">
                                    <span class="cat-links">
                                        <?php the_category(',', '', $content['id'])?>
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']);?>" tabindex="0"><?php echo esc_html($content['title']) ?></a></h2>
                                    </header>

                                    <?php ultragym_pro_posted_on($content['id']); ?>

                                    <div class="featured-image">
                                        <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>" title="<?php echo esc_url($content['title']); ?>"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']);?></p>
                                    </div><!-- .entry-content -->

                                    <?php if(!empty($options['popular_post_btn_title']) ): ?>
                                        <div class="read-more">
                                            <a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($options['popular_post_btn_title']); ?></a>
                                            <span class="more-line"></span>
                                        </div><!-- .read-more  -->
                                    <?php endif; ?>
                                </div><!-- .blog-post-wrapper -->
                            </article>
                        <?php endforeach; ?>

                    </div><!--primary -->
                </div><!--wrapper -->
            </div><!-- bog-latest-posts -->
        </div>
        
    <?php }
endif;  ?>
