<?php
/**
 * Services section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_service_section() {
    	$options = ultragym_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'ultragym_pro_section_status', true, 'service_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'pro-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design' ) ) ) {
            $service_enable = false;
        }

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        ultragym_pro_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultragym_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input service section details.
    */
    function ultragym_pro_get_service_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        $service_content_type  = $options['service_content_type'];
        $service_posts_count = ! empty( $options['service_posts_count'] ) ? $options['service_posts_count'] : 2;
        
        $content = array();
        switch ( $service_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_posts_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $service_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_posts_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $service_posts_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_category'] ) ? $options['service_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $service_posts_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['content']   = ultragym_pro_trim_content(20);
                $page_post['url']       = get_the_permalink();
                $page_post['author']    = ultragym_pro_author();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'ultragym_pro_filter_service_section_details', 'ultragym_pro_get_service_section_details' );


if ( ! function_exists( 'ultragym_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_service_section( $content_details = array() ) {
        $options    = ultragym_pro_get_theme_options();
        $service_sub_title  = $options['service_section_sub_title'];
        $service_title      = isset($options['service_section_title']) ? $options['service_section_title']: '';
        $service_bg_image   = (isset($options['service_bg_image']) && in_array( $options['home_layout'], array( 'default-design', 'pro-design', 'second-design')) ) ? $options['service_bg_image']: '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultragym_pro_service_section">
            <div id="our-services" class="page-section" style="background-image: url('<?php echo esc_url($service_bg_image); ?>');">
                <div class="wrapper">
                    <?php if(is_customize_preview()) ultragym_pro_section_tooltip('our-services'); ?>
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html($service_sub_title); ?></p>
                        <h2 class="section-title"><?php echo esc_html($service_title); ?></h2>
                    </div>

                    <div class="section-content col-3 clear">
                        <?php foreach ( $content_details as $i=>$content ) : ?>
                            <article>
                                <div class="service-item-wrapper">
                                    <div class="service-icon">
                                        <a href="<?php echo esc_url($content['url']); ?>">
                                            <i class="fa <?php echo esc_attr( !empty( $options['service_icon_' . (absint($i)+1)] ) ? $options['service_icon_' . (absint($i)+1)] : 'fa-podcast' ); ?>"></i>
                                        </a>
                                    </div><!-- .service-icon -->

                                    <?php if($options['home_layout'] == 'second-design') echo '<div class="entry-container">'; ?>

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo wp_kses_post($content['content']); ?></p>
                                        </div><!-- .entry-content -->

                                    <?php if($options['home_layout'] == 'second-design') echo '</div>'; ?>
                                    
                                </div><!-- .service-item-wrapper -->
                            </article>
                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- our-services -->
        </div>
       

    <?php
    }    
endif; ?>
