<?php
/**
 * Banner section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_slider_section() {
    	$options = ultragym_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'ultragym_pro_section_status', true, 'slider_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'pro-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design', 'sixth-design' ) ) ) {
            $slider_enable = false;
        }

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        ultragym_pro_render_slider_section( $section_details );
}

endif;

if ( ! function_exists( 'ultragym_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input slider section details.
    */
    function ultragym_pro_get_slider_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        $slider_content_type    = $options['slider_content_type'];
        $slider_count           = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 4;
        
        $content = array();
        switch ( $slider_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $slider_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_category'] ) ? $options['slider_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $slider_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = has_excerpt() ? get_the_excerpt() : ultragym_pro_trim_content(15);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'ultragym_pro_filter_slider_section_details', 'ultragym_pro_get_slider_section_details' );


if ( ! function_exists( 'ultragym_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_slider_section( $content_details = array() ) {
        $options = ultragym_pro_get_theme_options();
        $slider_autoplay_enable = ($options['slider_autoplay_enable']) ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultragym_pro_slider_section">
             <div id="featured-slider" <?php if($options['home_layout'] == 'fifth-design') echo 'class="wrapper"'; ?> data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows": true, "autoplay": <?php echo esc_attr($slider_autoplay_enable); ?>, "draggable": true, "fade": false }'>
                <?php foreach ( $content_details as $content ) : ?>
                    <article style="background-image:url('<?php echo $content['image']; ?>');">
                    <div class="overlay" <?php if($options['home_layout'] == 'default-design' || $options['home_layout'] == 'pro-design') echo "style='opacity: 0;'" ?>></div>
                        <div class="wrapper">
                            <div class="featured-content-wrapper">
                                <div class="entry-container">  

                                    <?php if(is_customize_preview()) ultragym_pro_section_tooltip('featured-slider'); ?>
                                    
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                </div><!-- .entry-content-->

                                <?php if(!empty($options['slider_btn_txt'])): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['slider_btn_txt']); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            </div> 

                        <?php  
                            if(has_nav_menu( 'social' ) && $options['slider_social_menu_enable']):
                
                                wp_nav_menu(  array(
                                    'theme_location' => 'social',
                                    'container' => 'div',
                                    'container_class' => 'social-icons',
                                    'echo' => true,
                                    'depth' => 1,
                                    'link_before' => '<span class="screen-reader-text">',
                                    'link_after' => '</span>',
                                    'fallback_cb' => false,
                                ) );
                                
                            endif; ?>

                        </div><!-- .featured-content-wrapper -->
                    </div><!-- .wrapper -->
                </article>
                <?php endforeach; ?>

            </div><!-- #featured-slider -->
        </div>
           
    <?php
    }    
endif;

