<?php
/**
 * Team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_team_section() {
    	$options = ultragym_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'ultragym_pro_section_status', true, 'team_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design','second-design', 'fourth-design','fifth-design') ) ) {
            $team_enable = false;
        }

        if ( true !== $team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        ultragym_pro_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultragym_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input team section details.
    */
    function ultragym_pro_get_team_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        
        $team_content_type  = $options['team_content_type'];
        $team_count = ! empty( $options['team_count'] ) ? $options['team_count'] : 4;

        $content = array();
        switch ( $team_content_type ) {
        	
            case 'page':
                $page_ids = array();
                $position = array();

                for ( $i = 1; $i <= absint($team_count); $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) ) :
                        $page_ids[] = $options['team_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint($team_count),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $position = array();

                for ( $i = 1; $i <= absint($team_count); $i++ ) {
                    if ( ! empty( $options['team_content_post_' . $i] ) ) :
                        $post_ids[] = $options['team_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint($team_count),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint($team_count),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['team_title_' . $i] ) ) :
                        $custom['title']        = $options['team_title_' . $i];
                        $custom['image']        = ! empty( $options['team_image_' . $i] ) ? $options['team_image_' . $i] : '';
                        $custom['url']          = ! empty( $options['team_link_' . $i] ) ? $options['team_link_' . $i] : '';
                        $custom['position']     = ! empty( $options['team_position_' . $i] ) ? $options['team_position_' . $i] : '';
                        $custom['social']     = ! empty( $options['team_social_' . $i] ) ? $options['team_social_' . $i] : '';
                        
                        // Push to the main array.
                        array_push( $content, $custom );

                    endif;
                    
                }
            break;


            default:
            break;
        }

        if ( 'custom' !== $team_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            $i = 1;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['position']  = (! empty(  $options['team_position_' . $i] ) ) ?  $options['team_position_' . $i] : '';
                    $page_post['social']    = (! empty( $options['team_social_' . $i] ) ) ? $options['team_social_' . $i] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnails' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'ultragym_pro_filter_team_section_details', 'ultragym_pro_get_team_section_details' );


if ( ! function_exists( 'ultragym_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_team_section( $content_details = array() ) {
        $options = ultragym_pro_get_theme_options();
        $column = ! empty( $options['team_column'] ) ? $options['team_column'] : 'col-4';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultragym_pro_team_section">
            <div id="team" class="page-section <?php if($options['home_layout'] == 'second-design') echo 'no-padding-top'; ?>">
            <?php if($options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'fifth-design') echo '<div class="wrapper">'; ?>
                <div class="section-header">
                <?php if(is_customize_preview()) ultragym_pro_section_tooltip('team'); ?>

                    <p class="section-subtitle"><?php echo esc_html( $options['team_sub_title'] ); ?></p>
                    <h2 class="section-title"><?php echo esc_html( $options['team_title'] ); ?></h2>
                </div><!-- .section-header -->

                <?php if($options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'fifth-design'): ?>
                    <div class="team-wrapper <?php echo esc_attr( $column ); ?> clear">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article class="hentry">
                                <div class="team-item-wrapper">
                                    <div class="featured-image" style="background-image:url('<?php echo esc_url( $content['image'] ); ?>')">
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            <?php if(!empty($content['position'])) echo '<span>'.esc_html( $content['position'] ).'</span>'; ?>
                                        </header>
                                    </div><!-- .entry-container -->
                                </div><!-- .team-item-wrapper -->
                            </article>
                        <?php endforeach; ?>
                    </div>
                <?php else: ?>
                    <div class="<?php echo esc_attr( $column ); ?> clear">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <div class="overlay"></div>
                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            <?php if(!empty($content['position'])) echo '<span>'.esc_html( $content['position'] ).'</span>'; ?>
                                        </header>

                                        <?php
                                        if ( ! empty( $content['social'] ) ) : 
                                            $social = explode( '|', $content['social'] ); ?>
                                            <div class="social-icons">
                                                <ul>
                                                    <?php foreach( $social as $social_link ) : ?>
                                                        <li>
                                                            <a href="<?php echo esc_url( $social_link ); ?>">
                                                                <?php echo ultragym_pro_return_social_icon( $social_link ); ?>
                                                            </a>
                                                        </li>
                                                    <?php endforeach; ?>
                                                </ul>
                                            </div>
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-image -->
                            </article><!-- article -->
                        <?php endforeach; ?>

                    </div><!-- .col-4 -->
                <?php endif;
            if($options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'fifth-design') echo '</div>'; ?>

            </div><!-- #team -->
        </div>
            
   
    <?php }
endif;