<?php
/**
 * Testimonial section
 *
 * This is the template for the content of Testimonial section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */

if ( ! function_exists( 'ultragym_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_testimonial_section() {
    	$options = ultragym_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'ultragym_pro_section_status', true, 'testimonial_section_enable' );

         if ( !in_array( $options['home_layout'], array( 'default-design', 'pro-design', 'second-design', 'third-design', 'fourth-design') ) ) {
             $testimonial_enable = false;
        }

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_testimonial_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render testimonial section now.
        ultragym_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultragym_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function ultragym_pro_get_testimonial_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        $testimonial_content_type   = $options['testimonial_content_type'];
        $testimonial_count          = isset($options['testimonial_posts_count'] ) ? $options['testimonial_posts_count'] : 2;

        $content = array();
        switch ( $testimonial_content_type ) {
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) )
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) )
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                }

                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $testimonial_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_category'] ) ? $options['testimonial_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $testimonial_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );
            break;

            default:
            break;
        }
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) :
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['content']        = ultragym_pro_trim_content(25);
                $page_post['title']          = get_the_title();
                $page_post['url']            = get_the_permalink();
                $page_post['image']          = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['designation']    = isset($options['testimonial_post_designation_'.$i])?$options['testimonial_post_designation_'.$i] : '';
                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'ultragym_pro_filter_testimonial_section_details', 'ultragym_pro_get_testimonial_section_details' );


if ( ! function_exists( 'ultragym_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_testimonial_section( $content_details = array() ) {
    $options            = ultragym_pro_get_theme_options();
    $testimonial_bg_image = (!empty($options['testimonial_bg_image']) && $options['home_layout'] != 'second-design') ? $options['testimonial_bg_image'] : '';

    if ( empty( $content_details ) ) {
        return;
    } ?>
    <div id="ultragym_pro_testimonial_section">
        <div id="testimonial" class="relative page-section" style="background-image:url('<?php echo esc_url($testimonial_bg_image); ?>')">
            <div class="overlay"></div>
            <div class="wrapper">
            <?php if(is_customize_preview()) ultragym_pro_section_tooltip('testimonial'); ?>

                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html($options['testimonial_section_sub_title']); ?></p>
                    <h2 class="section-title"><?php echo esc_html($options['testimonial_section_title']); ?></h2>
                </div><!-- .section-header -->

                <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": false, "arrows":true, "autoplay": true, "draggable": true, "fade": false }'>
                    <?php foreach($content_details as $content): ?>
                        <article>
                            <div class="entry-container">
                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['content']); ?></p>
                                </div><!-- .entry-content -->
                                <div class="seperator"></div>

                                <div class="header-wrapper">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                        <p class="designation"><?php echo esc_html($content['designation']); ?></p>
                                    </header>
                                </div><!-- .header-wrapper -->

                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .client-slider -->
            </div><!-- .wrapper -->
        </div><!-- #testimonial -->
    </div>
       

    <?php
    }
endif; ?>
