<?php
/**
 * Banner section
 *
 * This is the template for the content of video section
 *
 * @package Theme Palace
 * @subpackage  UltraGym Pro
 * @since  UltraGym Pro 1.0.0
 */
if ( ! function_exists( 'ultragym_pro_add_video_section' ) ) :
    /**
    * Add video section
    *
    *@since  UltraGym Pro 1.0.0
    */
    function ultragym_pro_add_video_section() {
    	$options = ultragym_pro_get_theme_options();
        // Check if video is enabled on frontpage
        $video_enable = apply_filters( 'ultragym_pro_section_status', true, 'video_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'pro-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design') ) ) {
            $video_enable = false;
        }

        if ( true !== $video_enable ) {
            return false;
        }
        // Get video section details
        $section_details = array();
        $section_details = apply_filters( 'ultragym_pro_filter_video_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render video section now.
        ultragym_pro_render_video_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultragym_pro_get_video_section_details' ) ) :
    /**
    * video section details.
    *
    * @since  UltraGym Pro 1.0.0
    * @param array $input video section details.
    */
    function ultragym_pro_get_video_section_details( $input ) {
        $options = ultragym_pro_get_theme_options();

        // Content type.
        $video_content_type  = $options['video_content_type'];
        $video_count = ! empty( $options['video_count'] ) ? $options['video_count'] : 1;
        
        $content = array();
        switch ( $video_content_type ) {
            case 'page':
                $page_id = '';
                if ( ! empty( $options['video_content_page'] ) )
                    $page_id = isset($options['video_content_page']) ? $options['video_content_page'] : '' ;
                $args = array(
                    'post_type'             => 'page',
                    'p'                     =>  absint( $page_id ),
                    'ignore_sticky_posts'   => true,
                    );
                break;

            case 'post':
                $post_id = '';
                if ( ! empty( $options['video_content_post'] ) )
                    $post_id = isset($options['video_content_post'])?$options['video_content_post']:'';
                $args = array(
                    'post_type'             => 'post',
                    'p'                     => absint( $post_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
                break;

            case 'category':
                $cat_id = isset( $options['video_category'] ) ? $options['video_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
                break;
            case 'custom':
                $page_post['content']   = isset($options['video_custom_content']) ? $options['video_custom_content'] : '';
                $page_post['title']     = isset($options['video_custom_title'])? $options['video_custom_title']: '';
                $page_post['image']     = isset($options['video_custom_image'])? $options['video_custom_image']: get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                array_push( $content, $page_post );
                return $content;
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['content']       = has_excerpt() ? get_the_excerpt() : ultragym_pro_trim_content(30);
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['image_large']   = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['url']           = get_the_permalink( );
                $page_post['title']         = get_the_title();
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// video section content details.
add_filter( 'ultragym_pro_filter_video_section_details', 'ultragym_pro_get_video_section_details' );


if ( ! function_exists( 'ultragym_pro_render_video_section' ) ) :
  /**
   * Start video section
   *
   * @return string video content
   * @since  UltraGym Pro 1.0.0
   *
   */
   function ultragym_pro_render_video_section( $content_details = array() ) {
        $options        = ultragym_pro_get_theme_options();
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php $content = $content_details[0]; ?>
        <div id="ultragym_pro_video_section">
            <div id="video" class="page-section" <?php if($options['home_layout'] == 'second-design') echo 'style="background-image: url('.$content['image_large'].');"' ?>>
                <?php if($options['home_layout'] == 'second-design') echo '<div class="overlay"></div>'; ?>

                <div class="wrapper">
                    <article class="has-post-thumbnail">
                        <?php if( in_array($options['home_layout'], array('default-design', 'pro-design', 'fourth-design', 'fifth-design', 'third-design')) ) echo '<div class="entry-container">'; ?>
                            <?php if(is_customize_preview()) ultragym_pro_section_tooltip('video'); ?>

                            <div class="section-header">
                                
                                <p class="section-subtitle"><?php echo esc_html($options['video_section_title']); ?></p>
                                <h2 class="section-title"><?php echo esc_html($content['title']); ?></h2>
                            </div><!-- .section-header -->

                            <?php if( in_array($options['home_layout'], array('default-design', 'pro-design', 'third-design', 'fourth-design', 'fifth-design')) ): ?>
                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['content']); ?></p>
                                </div><!-- .entry-content -->

                                <?php if(!empty($options['video_btn_label'])): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['video_btn_label'])?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            <?php endif; ?>

                        <?php if( in_array($options['home_layout'], array('default-design', 'pro-design', 'fourth-design', 'fifth-design', 'third-design')) ) echo '</div>'; ?>

                        <?php if( in_array($options['home_layout'], array('default-design', 'pro-design', 'third-design', 'fourth-design', 'fifth-design')) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                <a href="<?php echo esc_url($content['url']); ?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']); ?>"></a>
                        <?php endif; ?>
                        
                            <?php if(!empty($options['video_url'])): ?>
                                <div class="video-button">
                                    <a href="<?php echo esc_url($options['video_url']); ?>" class="popup-youtube">
                                        <svg class="svg-inline--fa fa-play fa-w-14" viewBox="0 0 448 512"><path d="M424.4 214.7L72.4 6.6C43.8-10.3 0 6.1 0 47.9V464c0 37.5 40.7 60.1 72.4 41.3l352-208c31.4-18.5 31.5-64.1 0-82.6z"></path></svg>
                                    </a>
                                </div>
                            <?php endif; ?>
                        <?php if( in_array($options['home_layout'], array('default-design', 'pro-design', 'fourth-design', 'fifth-design', 'third-design')) ) echo '</div>'; ?>
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #video --> 
        </div>
       

    <?php
    }    
endif; ?>
